# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/featurestore/api/v1/CoreService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ai.h2o.featurestore.api.v1 import FeatureSetSearch_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetSearch__pb2
from ai.h2o.featurestore.api.v1 import OnlineApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2
from ai.h2o.featurestore.api.v1 import TimeToLiveApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_TimeToLiveApi__pb2
from ai.h2o.featurestore.api.v1 import FeatureSetProtoApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2
from ai.h2o.featurestore.api.v1 import RecommendationProtoApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2
from ai.h2o.featurestore.api.v1 import DashboardApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_DashboardApi__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ai/h2o/featurestore/api/v1/CoreService.proto\x12\x1a\x61i.h2o.featurestore.api.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x31\x61i/h2o/featurestore/api/v1/FeatureSetSearch.proto\x1a*ai/h2o/featurestore/api/v1/OnlineApi.proto\x1a.ai/h2o/featurestore/api/v1/TimeToLiveApi.proto\x1a\x33\x61i/h2o/featurestore/api/v1/FeatureSetProtoApi.proto\x1a\x37\x61i/h2o/featurestore/api/v1/RecommendationProtoApi.proto\x1a-ai/h2o/featurestore/api/v1/DashboardApi.proto\"\xa9\x01\n\x1e\x46\x65\x61tureCustomDataUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x1d\n\x15\x61\x62solute_feature_name\x18\x02 \x01(\t\x12*\n\tnew_value\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"R\n\x17IdentityProviderDetails\x12\x14\n\x0cidp_meta_url\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x0e\n\x06scopes\x18\x03 \x03(\t\"w\n\x14GetWebConfigResponse\x12H\n\x0bipd_details\x18\x01 \x01(\x0b\x32\x33.ai.h2o.featurestore.api.v1.IdentityProviderDetails\x12\x15\n\rapp_store_url\x18\x02 \x01(\t\"\x8d\x01\n!FeatureSetCustomDataUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12*\n\tnew_value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"`\n\x1eProjectCustomDataUpdateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12*\n\tnew_value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x9a\x01\n\x1b\x46\x65\x61tureSetTypeUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12=\n\tnew_value\x18\x02 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.FeatureSetType\"m\n-GetFeatureSetsLastMinorForCurrentMajorRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\"\xb3\x01\n\x18\x46\x65\x61tureTypeUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x1d\n\x15\x61\x62solute_feature_name\x18\x02 \x01(\t\x12:\n\tnew_value\x18\x03 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\"\x91\x01\n\x1f\x46\x65\x61tureDoubleFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x1d\n\x15\x61\x62solute_feature_name\x18\x02 \x01(\t\x12\x11\n\tnew_value\x18\x03 \x01(\x01\"\x91\x01\n\x1f\x46\x65\x61tureStringFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x1d\n\x15\x61\x62solute_feature_name\x18\x02 \x01(\t\x12\x11\n\tnew_value\x18\x03 \x01(\t\"\x96\x01\n$FeatureStringArrayFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x1d\n\x15\x61\x62solute_feature_name\x18\x02 \x01(\t\x12\x11\n\tnew_value\x18\x03 \x03(\t\"\x92\x01\n FeatureBooleanFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x1d\n\x15\x61\x62solute_feature_name\x18\x02 \x01(\t\x12\x11\n\tnew_value\x18\x03 \x01(\x08\"\xbd\x01\n3FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12H\n\tnew_value\x18\x02 \x01(\x0e\x32\x35.ai.h2o.featurestore.api.v1.Online.TimeToLiveInterval\"\xbf\x01\n4FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12I\n\tnew_value\x18\x02 \x01(\x0e\x32\x36.ai.h2o.featurestore.api.v1.Offline.TimeToLiveInterval\"r\n\x1f\x46\x65\x61tureSetIntFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x11\n\tnew_value\x18\x02 \x01(\x05\"\xae\x01\n*FeatureSetProcessIntervalUnitUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x42\n\tnew_value\x18\x02 \x01(\x0e\x32/.ai.h2o.featurestore.api.v1.ProcessIntervalUnit\"z\n\'FeatureSetStringArrayFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x11\n\tnew_value\x18\x02 \x03(\t\"v\n#FeatureSetBooleanFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x11\n\tnew_value\x18\x02 \x01(\x08\"u\n\"FeatureSetStringFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x11\n\tnew_value\x18\x02 \x01(\t\"\x9e\x01\n FeatureSetUserFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12<\n\tnew_value\x18\x02 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\"I\n ProjectBooleanFieldUpdateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x11\n\tnew_value\x18\x02 \x01(\x08\"H\n\x1fProjectStringFieldUpdateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x11\n\tnew_value\x18\x02 \x01(\t\"q\n\x1dProjectUserFieldUpdateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12<\n\tnew_value\x18\x02 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\"E\n\x17\x46\x65\x61tureSetExistsRequest\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\"V\n\x17GetIngestHistoryRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"*\n\x14ProjectExistsRequest\x12\x12\n\nproject_id\x18\x02 \x01(\t\" \n\x0e\x45xistsResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\")\n\x17ProjectsDefaultResponse\x12\x0e\n\x06locked\x18\x01 \x01(\x08\"P\n\x1eHasPermissionToRetrieveRequest\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\"B\n\x1fHasPermissionToRetrieveResponse\x12\x1f\n\x17has_retrieve_permission\x18\x01 \x01(\x08\"m\n\x1bStartRevertIngestJobRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12\x11\n\tingest_id\x18\x02 \x01(\t\"e\n\x12OnlineRetrieveMeta\x12\x17\n\x0f\x62\x61se_online_url\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x12\n\nis_enabled\x18\x04 \x01(\x08\",\n\x13RefreshTokenRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"%\n\x14GetUserByMailRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"P\n\x15GetUserByMailResponse\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\" \n\x0cTokenRequest\x12\x10\n\x08token_id\x18\x01 \x01(\t\"j\n\x14GenerateTokenRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12/\n\x0b\x65xpiry_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"O\n\rTokenResponse\x12>\n\x05token\x18\x01 \x01(\x0b\x32/.ai.h2o.featurestore.api.v1.PersonalAccessToken\"U\n\x12ListTokensResponse\x12?\n\x06tokens\x18\x01 \x03(\x0b\x32/.ai.h2o.featurestore.api.v1.PersonalAccessToken\"!\n\x10RawTokenResponse\x12\r\n\x05token\x18\x01 \x01(\t\"\x95\x01\n\x0fListJobsRequest\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12;\n\x0b\x66\x65\x61ture_set\x18\x02 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12\x35\n\x08job_type\x18\x03 \x01(\x0e\x32#.ai.h2o.featurestore.api.v1.JobType\"A\n\x10ListJobsResponse\x12-\n\x04jobs\x18\x01 \x03(\x0b\x32\x1f.ai.h2o.featurestore.api.v1.Job\"\xc5\x01\n$FeatureSetSchemaCompatibilityRequest\x12\x42\n\x0foriginal_schema\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12=\n\nnew_schema\x18\x02 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12\x1a\n\x12\x63ompare_data_types\x18\x03 \x01(\x08\">\n%FeatureSetSchemaCompatibilityResponse\x12\x15\n\ris_compatible\x18\x01 \x01(\x08\"\xbd\x01\n\x1c\x46\x65\x61tureSetSchemaPatchRequest\x12\x42\n\x0foriginal_schema\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12=\n\nnew_schema\x18\x02 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12\x1a\n\x12\x63ompare_data_types\x18\x03 \x01(\x08\"Z\n\x1d\x46\x65\x61tureSetSchemaPatchResponse\x12\x39\n\x06schema\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\"\x17\n\x05JobId\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"W\n\x18GetRecommendationRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"\xaf\x02\n\x19GetRecommendationResponse\x12L\n\x07matches\x18\x01 \x03(\x0b\x32;.ai.h2o.featurestore.api.v1.GetRecommendationResponse.Match\x1a+\n\x04Join\x12\x12\n\nclassifier\x18\x01 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\x1a\x96\x01\n\x05Match\x12\x42\n\x12target_feature_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12I\n\x05joins\x18\x02 \x03(\x0b\x32:.ai.h2o.featurestore.api.v1.GetRecommendationResponse.Join\"o\n\x03Job\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x35\n\x08job_type\x18\x02 \x01(\x0e\x32#.ai.h2o.featurestore.api.v1.JobType\x12\x0c\n\x04\x64one\x18\x03 \x01(\x08\x12\x13\n\x0b\x63hildJobIds\x18\x04 \x03(\t\"6\n\x10JobProgressInput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x12\n\nnext_index\x18\x02 \x01(\x05\"\xc6\x01\n\x11JobProgressOutput\x12H\n\x08progress\x18\x01 \x03(\x0b\x32\x36.ai.h2o.featurestore.api.v1.JobProgressOutput.Progress\x1ag\n\x08Progress\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x1b\n\x13\x64uration_in_seconds\x18\x02 \x01(\r\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xaf\x01\n\x1b\x46\x65\x61tureSetPermissionRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12\x13\n\x0buser_emails\x18\x02 \x03(\t\x12>\n\npermission\x18\x03 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.PermissionType\"\xa5\x01\n\x18ProjectPermissionRequest\x12\x34\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\x12\x13\n\x0buser_emails\x18\x02 \x03(\t\x12>\n\npermission\x18\x03 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.PermissionType\"\xe8\x01\n\x1cStartExtractSchemaJobRequest\x12?\n\x08raw_data\x18\x01 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocationH\x00\x12\x46\n\x0c\x64\x65rived_from\x18\x03 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformationH\x00\x12\x35\n\x04\x63red\x18\x02 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.CredentialsB\x08\n\x06source\"\x98\x01\n\x15\x45xtractSchemaResponse\x12\x39\n\x06schema\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12\x44\n\x0c\x64\x65rived_from\x18\x02 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformation\"\\\n\x1dListFeatureSetsVersionRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"\x81\x01\n\x12\x46\x65\x61tureSetResponse\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12.\n\x03job\x18\x02 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.JobId\"_\n\x18UpdateFeatureSetResponse\x12\x43\n\x13updated_feature_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"U\n\x15UpdateProjectResponse\x12<\n\x0fupdated_project\x18\x02 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\"\x9a\x01\n\x15UpdateFeatureResponse\x12\x43\n\x13updated_feature_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12<\n\x0fupdated_feature\x18\x02 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\"G\n\x0fProjectResponse\x12\x34\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\"I\n\rLoginResponse\x12\x13\n\tlogin_url\x18\x01 \x01(\tH\x00\x12\x17\n\rrefresh_token\x18\x02 \x01(\tH\x00\x42\n\n\x08response\"P\n\x15GetActiveUserResponse\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\")\n\x11GetProjectRequest\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\"V\n\x17\x44\x65leteFeatureSetRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"&\n\rLogoutRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"8\n\rUserBasicInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\"Y\n\x04User\x12\x42\n\x0fuser_basic_info\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\r\n\x05\x61\x64min\x18\x02 \x01(\x08\"y\n\x13\x41\x63\x63\x65ssTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\x03\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x12\n\ntoken_type\x18\x05 \x01(\t\"L\n\x14\x44\x65leteProjectRequest\x12\x34\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\"T\n\x1cUpdateProjectMetadataRequest\x12\x34\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\"\x8f\x01\n\x14\x43reateProjectRequest\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06secret\x18\x03 \x01(\x08\x12\x0e\n\x06locked\x18\x04 \x01(\x08\x12,\n\x0b\x63ustom_data\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"e\n\x15\x43reateProjectResponse\x12\x34\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\x12\x16\n\x0e\x61lready_exists\x18\x02 \x01(\x08\"M\n\x14ListProjectsResponse\x12\x35\n\x08projects\x18\x01 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\"`\n\x18GetIngestHistoryResponse\x12\x44\n\x0eingest_history\x18\x01 \x03(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetIngest\"o\n$ListFeatureSetsAcrossProjectsRequest\x12\x15\n\rproject_names\x18\x01 \x03(\t\x12\x30\n\x05query\x18\x02 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Query\"\x8c\x01\n\x1aListFeatureSetsPageRequest\x12\x15\n\rproject_names\x18\x01 \x03(\t\x12\x30\n\x05query\x18\x02 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Query\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\"t\n\x1bListFeatureSetsPageResponse\x12<\n\x0c\x66\x65\x61ture_sets\x18\x01 \x03(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x85\x01\n\x0e\x41WSCredentials\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x14\n\x0csecret_token\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x04 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x05 \x01(\t\x12\x10\n\x08role_arn\x18\x06 \x01(\t\"\xa6\x01\n\x10\x41zureCredentials\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63\x63ount_key\x18\x02 \x01(\t\x12\x11\n\tsas_token\x18\x03 \x01(\t\x12\x15\n\rsas_container\x18\x04 \x01(\t\x12\x14\n\x0csp_client_id\x18\x05 \x01(\t\x12\x14\n\x0csp_tenant_id\x18\x06 \x01(\t\x12\x11\n\tsp_secret\x18\x07 \x01(\t\"6\n\x14SnowflakeCredentials\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"1\n\x0fJDBCCredentials\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\x92\x02\n\x0b\x43redentials\x12\x37\n\x03\x61ws\x18\x01 \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.AWSCredentials\x12;\n\x05\x61zure\x18\x02 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.AzureCredentials\x12\x43\n\tsnowflake\x18\x03 \x01(\x0b\x32\x30.ai.h2o.featurestore.api.v1.SnowflakeCredentials\x12\x42\n\rjdbc_database\x18\x04 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.JDBCCredentialsJ\x04\x08\x05\x10\x06\"W\n\x17ListFeatureSetsResponse\x12<\n\x0c\x66\x65\x61ture_sets\x18\x01 \x03(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"l\n\x1eListFeatureSetVersionsResponse\x12J\n\x08versions\x18\x01 \x03(\x0b\x32\x38.ai.h2o.featurestore.api.v1.FeatureSetVersionDescription\"~\n\x1c\x46\x65\x61tureSetVersionDescription\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x16\n\x0eversion_change\x18\x02 \x01(\t\x12\x35\n\x11\x63reated_date_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"w\n\x14GetFeatureSetRequest\x12\x34\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\xd9\x01\n\x15StartIngestJobRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12\x35\n\x04\x63red\x18\x02 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.Credentials\x12@\n\x0b\x64\x61ta_source\x18\x05 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocationJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"\xd8\x02\n\x0eIngestResponse\x12\x43\n\x04meta\x18\x01 \x01(\x0b\x32\x35.ai.h2o.featurestore.api.v1.IngestResponse.IngestMeta\x12;\n\x0b\x66\x65\x61ture_set\x18\x02 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x1a\xc3\x01\n\nIngestMeta\x12\x16\n\x0e\x63\x61\x63he_location\x18\x01 \x01(\t\x12\x1a\n\x12raw_cache_location\x18\x02 \x01(\t\x12\x37\n\x13ingestion_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x0cingest_scope\x18\x04 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xa5\x01\n\x0fRetrieveRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12\x17\n\x0fstart_date_time\x18\x02 \x01(\t\x12\x15\n\rend_date_time\x18\x03 \x01(\t\x12\x11\n\tingest_id\x18\x04 \x01(\t\x12\x12\n\nsession_id\x18\x05 \x01(\t\"\x8b\x01\n\x17RetrieveAsLinksResponse\x12\x16\n\x0e\x64ownload_links\x18\x01 \x03(\t\x12\x39\n\x0eretrieve_scope\x18\x02 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x1d\n\x15retrieve_job_executed\x18\x03 \x01(\x08\"\x96\x02\n\x17RetrieveAsSparkResponse\x12\x12\n\ncache_path\x18\x01 \x01(\t\x12Q\n\x07options\x18\x02 \x03(\x0b\x32@.ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse.OptionsEntry\x12\x39\n\x0eretrieve_scope\x18\x03 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x12\n\nsession_id\x18\x04 \x01(\t\x12\x15\n\rdelta_version\x18\x05 \x01(\x03\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"M\n\x0ePreviewRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"`\n!StartMaterializationOnlineRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"v\n\x1dMaterializationOnlineResponse\x12@\n\x15materialization_scope\x18\x01 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x13\n\x0bnum_records\x18\x02 \x01(\x04\"2\n\x1cIngestWriteCredentialRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\xca\x01\n\x1dIngestWriteCredentialResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\x12W\n\x07options\x18\x02 \x03(\x0b\x32\x46.ai.h2o.featurestore.api.v1.IngestWriteCredentialResponse.OptionsEntry\x12\x12\n\nsession_id\x18\x03 \x01(\t\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xed\x05\n\x0fRawDataLocation\x12\x36\n\x03\x63sv\x18\x01 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.CSVFileSpecH\x00\x12>\n\x07parquet\x18\x02 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.ParquetFileSpecH\x00\x12\x43\n\tsnowflake\x18\x03 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.SnowflakeTableSpecH\x00\x12\x39\n\x04jdbc\x18\x04 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.JDBCTableSpecH\x00\x12\x38\n\x04json\x18\x07 \x01(\x0b\x32(.ai.h2o.featurestore.api.v1.JSONFileSpecH\x00\x12\x41\n\x0b\x64\x65lta_table\x18\x08 \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.DeltaTableSpecH\x00\x12?\n\ncsv_folder\x18\n \x01(\x0b\x32).ai.h2o.featurestore.api.v1.CSVFolderSpecH\x00\x12G\n\x0eparquet_folder\x18\x0b \x01(\x0b\x32-.ai.h2o.featurestore.api.v1.ParquetFolderSpecH\x00\x12\x41\n\x0bjson_folder\x18\x0c \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.JSONFolderSpecH\x00\x12G\n\x0ctemp_parquet\x18\r \x01(\x0b\x32/.ai.h2o.featurestore.api.v1.TempParquetFileSpecH\x00\x12\x45\n\ronline_source\x18\x0e \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.OnlineSourceSpecH\x00\x42\x08\n\x06source\"5\n\x10OnlineSourceSpec\x12!\n\x19\x61\x62solute_json_folder_path\x18\x01 \x01(\t\".\n\x0b\x43SVFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tdelimiter\x18\x02 \x01(\t\"/\n\x0cJSONFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tmultiline\x18\x02 \x01(\x08\"\x1f\n\x0fParquetFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\"#\n\x13TempParquetFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\"C\n\x05Proxy\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\"\xd7\x01\n\x12SnowflakeTableSpec\x12\r\n\x05table\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\x12\x11\n\twarehouse\x18\x05 \x01(\t\x12\x0e\n\x06schema\x18\x06 \x01(\t\x12\x10\n\x08insecure\x18\x07 \x01(\x08\x12\x30\n\x05proxy\x18\x08 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Proxy\x12\x0c\n\x04role\x18\t \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\n \x01(\t\"\xb5\x01\n\rJDBCTableSpec\x12\r\n\x05table\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x16\n\x0e\x63onnection_url\x18\x03 \x01(\t\x12\x16\n\x0enum_partitions\x18\x04 \x01(\x05\x12\x18\n\x10partition_column\x18\x05 \x01(\t\x12\x13\n\x0blower_bound\x18\x06 \x01(\x04\x12\x13\n\x0bupper_bound\x18\x07 \x01(\x04\x12\x12\n\nfetch_size\x18\x08 \x01(\x05\"v\n\x0e\x44\x65ltaTableSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x11\n\ttimestamp\x18\x03 \x01(\t\x12\x32\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\".ai.h2o.featurestore.api.v1.Filter\"O\n\rCSVFolderSpec\x12\x13\n\x0broot_folder\x18\x01 \x01(\t\x12\x16\n\x0e\x66ilter_pattern\x18\x02 \x01(\t\x12\x11\n\tdelimiter\x18\x03 \x01(\t\"@\n\x11ParquetFolderSpec\x12\x13\n\x0broot_folder\x18\x01 \x01(\t\x12\x16\n\x0e\x66ilter_pattern\x18\x02 \x01(\t\"P\n\x0eJSONFolderSpec\x12\x13\n\x0broot_folder\x18\x01 \x01(\t\x12\x16\n\x0e\x66ilter_pattern\x18\x02 \x01(\t\x12\x11\n\tmultiline\x18\x03 \x01(\x08\"&\n\x12MojoTransformation\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\"/\n\x1bSparkPipelineTransformation\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\"9\n\x12JoinTransformation\x12\x10\n\x08left_key\x18\x01 \x01(\t\x12\x11\n\tright_key\x18\x02 \x01(\t\"0\n\x0bVersionedId\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rmajor_version\x18\x02 \x01(\r\"\xec\x01\n\x0eTransformation\x12>\n\x04mojo\x18\x02 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.MojoTransformationH\x00\x12Q\n\x0espark_pipeline\x18\x03 \x01(\x0b\x32\x37.ai.h2o.featurestore.api.v1.SparkPipelineTransformationH\x00\x12>\n\x04join\x18\x04 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.JoinTransformationH\x00\x42\x07\n\x05value\"\x9a\x01\n\x12\x44\x65rivedInformation\x12@\n\x0f\x66\x65\x61ture_set_ids\x18\x01 \x03(\x0b\x32\'.ai.h2o.featurestore.api.v1.VersionedId\x12\x42\n\x0etransformation\x18\x02 \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.Transformation\"J\n\x0fSelectedFeature\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x61ture\x18\x02 \x01(\t\x12\x16\n\x0etransformation\x18\x03 \x01(\t\"\xa1\x01\n\x14\x46ilterConditionUnion\x12;\n\x06\x66ilter\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureFilterH\x00\x12?\n\x05logic\x18\x02 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.FeatureFilterLogicH\x00\x42\x0b\n\tcondition\"\xa1\x01\n\rFeatureFilter\x12<\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.SelectedFeature\x12\x43\n\x08operator\x18\x02 \x01(\x0e\x32\x31.ai.h2o.featurestore.api.v1.FeatureFilterOperator\x12\r\n\x05value\x18\x03 \x01(\t\"\xe5\x01\n\x12\x46\x65\x61tureFilterLogic\x12>\n\x04left\x18\x01 \x01(\x0b\x32\x30.ai.h2o.featurestore.api.v1.FilterConditionUnion\x12?\n\x05right\x18\x02 \x01(\x0b\x32\x30.ai.h2o.featurestore.api.v1.FilterConditionUnion\x12N\n\x0elogic_operator\x18\x03 \x01(\x0e\x32\x36.ai.h2o.featurestore.api.v1.FeatureFilterLogicOperator\"\x83\x05\n\x0c\x46\x65\x61tureQuery\x12\x46\n\x11selected_features\x18\x01 \x03(\x0b\x32+.ai.h2o.featurestore.api.v1.SelectedFeature\x12G\n\x10\x66rom_feature_set\x18\x02 \x01(\x0b\x32-.ai.h2o.featurestore.api.v1.FeatureQuery.From\x12;\n\x04join\x18\x03 \x03(\x0b\x32-.ai.h2o.featurestore.api.v1.FeatureQuery.Join\x12?\n\x05where\x18\x04 \x01(\x0b\x32\x30.ai.h2o.featurestore.api.v1.FilterConditionUnion\x1aS\n\x04\x46rom\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.VersionedId\x12\r\n\x05\x61lias\x18\x02 \x01(\t\x1a\x8e\x02\n\x04Join\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.VersionedId\x12\r\n\x05\x61lias\x18\x02 \x01(\t\x12<\n\x02on\x18\x03 \x03(\x0b\x32\x30.ai.h2o.featurestore.api.v1.FeatureQuery.Join.On\x1a{\n\x02On\x12\x39\n\x04left\x18\x01 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.SelectedFeature\x12:\n\x05right\x18\x02 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.SelectedFeature\"\x9a\x01\n\x0b\x46\x65\x61tureView\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x37\n\x05query\x18\x06 \x01(\x0b\x32(.ai.h2o.featurestore.api.v1.FeatureQuery\"\x8a\x01\n\x18\x43reateFeatureViewRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x37\n\x05query\x18\x04 \x01(\x0b\x32(.ai.h2o.featurestore.api.v1.FeatureQuery\"f\n\x18UpdateFeatureViewRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\x94\x01\n\"CreateFeatureViewNewVersionRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12\x37\n\x05query\x18\x03 \x01(\x0b\x32(.ai.h2o.featurestore.api.v1.FeatureQuery\"J\n\x15GetFeatureViewRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\"T\n\x13\x46\x65\x61tureViewResponse\x12=\n\x0c\x66\x65\x61ture_view\x18\x01 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.FeatureView\"-\n\x17ListFeatureViewsRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"Z\n\x18ListFeatureViewsResponse\x12>\n\rfeature_views\x18\x01 \x03(\x0b\x32\'.ai.h2o.featurestore.api.v1.FeatureView\"\xc8\x01\n!RetrieveFeatureViewAsSparkRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12,\n\x08start_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65nd_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nsession_id\x18\x05 \x01(\t\"\xd4\x01\n\"RetrieveFeatureViewAsSparkResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\\\n\x07options\x18\x02 \x03(\x0b\x32K.ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkResponse.OptionsEntry\x12\x12\n\nsession_id\x18\x04 \x01(\t\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x01\n#RetrieveFeatureViewAsAsLinksRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12,\n\x08start_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65nd_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\">\n$RetrieveFeatureViewAsAsLinksResponse\x12\x16\n\x0e\x64ownload_links\x18\x01 \x03(\t\"3\n\x18\x44\x65leteFeatureViewRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\"\x8f\x03\n\x10MLDatasetFeature\x12\x12\n\nfeature_id\x18\x01 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x02 \x01(\t\x12!\n\x19\x66\x65\x61ture_set_major_version\x18\x03 \x01(\x05\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x04 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x05 \x01(\x05\x12\x11\n\tdata_type\x18\x06 \x01(\t\x12=\n\x0c\x66\x65\x61ture_type\x18\x07 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12\x15\n\rml_dataset_id\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x15\n\roriginal_name\x18\n \x01(\t\x12\x12\n\nproject_id\x18\x0b \x01(\t\x12\x1a\n\x12original_data_type\x18\x0c \x01(\t\x12\x1f\n\x17transformation_function\x18\r \x01(\t\x12\x16\n\x0eis_primary_key\x18\x0e \x01(\x08\"\xf6\x03\n\tMLDataset\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x33\n\x0fstart_date_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_date_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x06 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x07 \x01(\x05\x12\x12\n\nproject_id\x18\x08 \x01(\t\x12>\n\x08\x66\x65\x61tures\x18\t \x03(\x0b\x32,.ai.h2o.featurestore.api.v1.MLDatasetFeature\x12\x43\n\x05state\x18\n \x01(\x0e\x32\x34.ai.h2o.featurestore.api.v1.MLDataset.MLDatasetState\x12\x14\n\x0cprimary_keys\x18\x0b \x03(\t\"l\n\x0eMLDatasetState\x12\x1c\n\x18ML_DATASET_STATE_UNKNOWN\x10\x00\x12\x1c\n\x18ML_DATASET_STATE_PENDING\x10\x01\x12\x1e\n\x1aML_DATASET_STATE_AVAILABLE\x10\x02\"\xda\x01\n\x16\x43reateMLDatasetRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x33\n\x0fstart_date_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_date_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"D\n\x16UpdateMLDatasetRequest\x12\x15\n\rml_dataset_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"/\n\x16\x44\x65leteMLDatasetRequest\x12\x15\n\rml_dataset_id\x18\x01 \x01(\t\"\x84\x01\n\x17\x43reateMLDatasetResponse\x12\x39\n\nml_dataset\x18\x01 \x01(\x0b\x32%.ai.h2o.featurestore.api.v1.MLDataset\x12.\n\x03job\x18\x02 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.JobId\"e\n\x13GetMLDatasetRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12\x17\n\x0fml_dataset_name\x18\x03 \x01(\t\"N\n\x15ListMLDatasetsRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\"T\n\x16ListMLDatasetsResponse\x12:\n\x0bml_datasets\x18\x01 \x03(\x0b\x32%.ai.h2o.featurestore.api.v1.MLDataset\"L\n\x1fRetrieveMLDatasetAsSparkRequest\x12\x15\n\rml_dataset_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\"\xd0\x01\n RetrieveMLDatasetAsSparkResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\x12Z\n\x07options\x18\x02 \x03(\x0b\x32I.ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkResponse.OptionsEntry\x12\x12\n\nsession_id\x18\x04 \x01(\t\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n!RetrieveMLDatasetAsAsLinksRequest\x12\x15\n\rml_dataset_id\x18\x01 \x01(\t\"<\n\"RetrieveMLDatasetAsAsLinksResponse\x12\x16\n\x0e\x64ownload_links\x18\x01 \x03(\t\"E\n\x1eRetrieveMLDatasetOnlineRequest\x12\x15\n\rml_dataset_id\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\"\xc7\x0e\n\nFeatureSet\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x16\n\x0eversion_change\x18\x05 \x01(\t\x12\x1a\n\x12time_travel_column\x18\x06 \x01(\t\x12!\n\x19time_travel_column_format\x18\x07 \x01(\t\x12\x44\n\x10\x66\x65\x61ture_set_type\x18\x08 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.FeatureSetType\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x38\n\x05owner\x18\n \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x39\n\x06\x61uthor\x18\x0b \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x35\n\x11\x63reated_date_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_date_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10\x61pplication_name\x18\x0e \x01(\t\x12\x12\n\ndeprecated\x18\x0f \x01(\x08\x12\x33\n\x0f\x64\x65precated_date\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13\x64\x61ta_source_domains\x18\x11 \x03(\t\x12\x0c\n\x04tags\x18\x12 \x03(\t\x12\x18\n\x10process_interval\x18\x13 \x01(\r\x12N\n\x15process_interval_unit\x18\x14 \x01(\x0e\x32/.ai.h2o.featurestore.api.v1.ProcessIntervalUnit\x12\x0c\n\x04\x66low\x18\x15 \x01(\t\x12<\n\x0ctime_to_live\x18\x16 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.TimeToLive\x12\x35\n\x08\x66\x65\x61tures\x18\x17 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\x12\x45\n\nstatistics\x18\x18 \x01(\x0b\x32\x31.ai.h2o.featurestore.api.v1.FeatureSet.Statistics\x12H\n\x0cspecial_data\x18\x19 \x01(\x0b\x32\x32.ai.h2o.featurestore.api.v1.FeatureSet.SpecialData\x12\x13\n\x0bprimary_key\x18\x1a \x03(\t\x12\n\n\x02id\x18\x1c \x01(\t\x12<\n\x11time_travel_scope\x18\x1d \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x16\n\x0e\x61pplication_id\x18\x1e \x01(\t\x12\x19\n\x11\x66\x65\x61ture_set_state\x18\x1f \x01(\t\x12=\n\x06online\x18  \x01(\x0b\x32-.ai.h2o.featurestore.api.v1.FeatureSet.Online\x12\x0e\n\x06secret\x18! \x01(\x08\x12\x12\n\nproject_id\x18\" \x01(\t\x12\x14\n\x0cpartition_by\x18# \x03(\t\x12,\n\x0b\x63ustom_data\x18$ \x01(\x0b\x32\x17.google.protobuf.Struct\x12G\n\x1conline_materialization_scope\x18% \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x44\n\x0c\x64\x65rived_from\x18& \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformation\x12\x1b\n\x13\x66\x65\x61ture_classifiers\x18\' \x03(\t\x1a\"\n\nStatistics\x12\x14\n\x0c\x64\x61ta_latency\x18\x01 \x01(\x05\x1a\x82\x02\n\x0bSpecialData\x12\x0b\n\x03spi\x18\x01 \x01(\x08\x12\x0b\n\x03pci\x18\x02 \x01(\x08\x12\x0b\n\x03rpi\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65mographic\x18\x04 \x01(\x08\x12\x11\n\tsensitive\x18\x05 \x01(\x08\x12G\n\x05legal\x18\x06 \x01(\x0b\x32\x38.ai.h2o.featurestore.api.v1.FeatureSet.SpecialData.Legal\x1a[\n\x05Legal\x12\x10\n\x08\x61pproved\x18\x01 \x01(\x08\x12\x31\n\rapproved_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05notes\x18\x03 \x01(\t\x1aJ\n\x06Online\x12\x18\n\x10online_namespace\x18\x01 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\"R\n\x1bGetFeatureSetPreviewRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\"I\n\x1cGetFeatureSetPreviewResponse\x12\x13\n\x0bpreview_url\x18\x01 \x01(\t\x12\x14\n\x0cmax_cols_num\x18\x02 \x01(\r\"o\n\x05Scope\x12\x33\n\x0fstart_date_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_date_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xcf\x07\n\x19RegisterFeatureSetRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\x12\x34\n\x07project\x18\x02 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\x12\x1a\n\x12time_travel_column\x18\x03 \x01(\t\x12!\n\x19time_travel_column_format\x18\x04 \x01(\t\x12\x13\n\x0bprimary_key\x18\x05 \x03(\t\x12\x39\n\x06schema\x18\x07 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12\x0e\n\x06secret\x18\x08 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x14\n\x0cpartition_by\x18\n \x03(\t\x12\'\n\x1ftime_travel_column_as_partition\x18\x0b \x01(\x08\x12\x44\n\x10\x66\x65\x61ture_set_type\x18\x0c \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.FeatureSetType\x12\x19\n\x11\x66\x65\x61ture_set_state\x18\r \x01(\t\x12\x18\n\x10\x61pplication_name\x18\x0e \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x0f \x01(\t\x12=\n\x06online\x18\x10 \x01(\x0b\x32-.ai.h2o.featurestore.api.v1.FeatureSet.Online\x12\x1b\n\x13\x64\x61ta_source_domains\x18\x11 \x03(\t\x12\x0c\n\x04tags\x18\x12 \x03(\t\x12\x18\n\x10process_interval\x18\x13 \x01(\r\x12N\n\x15process_interval_unit\x18\x14 \x01(\x0e\x32/.ai.h2o.featurestore.api.v1.ProcessIntervalUnit\x12\x0c\n\x04\x66low\x18\x15 \x01(\t\x12H\n\x0cspecial_data\x18\x16 \x01(\x0b\x32\x32.ai.h2o.featurestore.api.v1.FeatureSet.SpecialData\x12,\n\x0b\x63ustom_data\x18\x17 \x01(\x0b\x32\x17.google.protobuf.Struct\x12<\n\x0ctime_to_live\x18\x18 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.TimeToLive\x12\x44\n\x0c\x64\x65rived_from\x18\x19 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformation\"\x97\x03\n!CreateNewFeatureSetVersionRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12\x39\n\x06schema\x18\x02 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12\x19\n\x11\x61\x66\x66\x65\x63ted_features\x18\x03 \x03(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x44\n\x0c\x64\x65rived_from\x18\x05 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformation\x12\x13\n\x0bprimary_key\x18\x06 \x03(\t\x12-\n%use_primary_key_from_previous_version\x18\x07 \x01(\x08\x12\x45\n\x10\x62\x61\x63kfill_options\x18\x08 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.BackfillOptions\"\xff\x01\n\x0e\x46\x65\x61tureProfile\x12=\n\x0c\x66\x65\x61ture_type\x18\x01 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12M\n\x0b\x63\x61tegorical\x18\x02 \x01(\x0b\x32\x38.ai.h2o.featurestore.api.v1.CategoricalFeatureStatistics\x12\x41\n\nstatistics\x18\x03 \x01(\x0b\x32-.ai.h2o.featurestore.api.v1.FeatureStatistics\x12\x1c\n\x14statistics_available\x18\x04 \x01(\x08\"\xff\x02\n\rFeatureSchema\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdata_type\x18\x02 \x01(\t\x12\x39\n\x06nested\x18\x03 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12K\n\x0cspecial_data\x18\x04 \x01(\x0b\x32\x35.ai.h2o.featurestore.api.v1.FeatureSchema.SpecialData\x12=\n\x0c\x66\x65\x61ture_type\x18\x05 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x13\n\x0b\x63lassifiers\x18\x07 \x03(\t\x1a\\\n\x0bSpecialData\x12\x0b\n\x03spi\x18\x01 \x01(\x08\x12\x0b\n\x03pci\x18\x02 \x01(\x08\x12\x0b\n\x03rpi\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65mographic\x18\x04 \x01(\x08\x12\x11\n\tsensitive\x18\x05 \x01(\x08\"\xb8\x05\n\x07\x46\x65\x61ture\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x16\n\x0eversion_change\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x11\n\tdata_type\x18\x05 \x01(\t\x12;\n\x07profile\x18\x06 \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.FeatureProfile\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x12\n\nimportance\x18\x08 \x01(\x01\x12\x0f\n\x07special\x18\t \x01(\t\x12\x42\n\nmonitoring\x18\n \x01(\x0b\x32..ai.h2o.featurestore.api.v1.Feature.Monitoring\x12<\n\x0fnested_features\x18\x0b \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\x12%\n\x1d\x66ully_qualified_feature_names\x18\x0c \x03(\t\x12\x45\n\x0cspecial_data\x18\r \x01(\x0b\x32/.ai.h2o.featurestore.api.v1.Feature.SpecialData\x12\x13\n\x0b\x63lassifiers\x18\x0e \x03(\t\x12,\n\x0b\x63ustom_data\x18\x0f \x01(\x0b\x32\x17.google.protobuf.Struct\x12\n\n\x02id\x18\x10 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x11 \x01(\t\x1a\'\n\nMonitoring\x12\x19\n\x11\x61nomaly_detection\x18\x01 \x01(\x08\x1a\\\n\x0bSpecialData\x12\x0b\n\x03spi\x18\x01 \x01(\x08\x12\x0b\n\x03pci\x18\x02 \x01(\x08\x12\x0b\n\x03rpi\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65mographic\x18\x04 \x01(\x08\x12\x11\n\tsensitive\x18\x05 \x01(\x08\"\xac\x01\n\x11\x46\x65\x61tureStatistics\x12\x0b\n\x03max\x18\x01 \x01(\x01\x12\x0c\n\x04mean\x18\x02 \x01(\x01\x12\x0e\n\x06median\x18\x03 \x01(\x01\x12\x0b\n\x03min\x18\x04 \x01(\x01\x12\x0e\n\x06stddev\x18\x05 \x01(\x01\x12\x18\n\x10stddev_rec_count\x18\x06 \x01(\x03\x12\x12\n\nnull_count\x18\x07 \x01(\x03\x12\x11\n\tnan_count\x18\x08 \x01(\x03\x12\x0e\n\x06unique\x18\t \x01(\x03\"\xab\x01\n\x1c\x43\x61tegoricalFeatureStatistics\x12\x0e\n\x06unique\x18\x01 \x01(\x03\x12P\n\x03top\x18\x02 \x03(\x0b\x32\x43.ai.h2o.featurestore.api.v1.CategoricalFeatureStatistics.FeatureTop\x1a)\n\nFeatureTop\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\"%\n\x12GetVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\"\x89\x03\n\x07Project\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x38\n\x05owner\x18\x03 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x39\n\x06\x61uthor\x18\x04 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x35\n\x11\x63reated_date_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_date_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06secret\x18\x07 \x01(\x08\x12\x0e\n\x06locked\x18\x08 \x01(\x08\x12\n\n\x02id\x18\t \x01(\t\x12,\n\x0b\x63ustom_data\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1a\n\x12\x66\x65\x61ture_sets_count\x18\x0b \x01(\x04\"\xa4\x02\n\x0fListableProject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x39\n\x15last_update_date_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06locked\x18\x05 \x01(\x08\x12@\n\npermission\x18\x06 \x01(\x0e\x32,.ai.h2o.featurestore.api.v1.ActivePermission\x12\x39\n\x06\x61uthor\x18\x07 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x1a\n\x12\x66\x65\x61ture_sets_count\x18\x08 \x01(\x04\"\x97\x02\n\x10\x46\x65\x61tureSetIngest\x12\x11\n\tingest_id\x18\x01 \x01(\t\x12\x34\n\x10ingest_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x06source\x18\x03 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocation\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x05 \x01(\t\x12\x30\n\x05scope\x18\x07 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x16\n\x0eparent_ingests\x18\x08 \x03(\t\"\xd7\x01\n\x13PersonalAccessToken\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12-\n\tlast_used\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rcreation_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x65xpiry_date\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x88\x01\n#GenerateTransformationUploadRequest\x12K\n\x13transformation_type\x18\x01 \x01(\x0e\x32..ai.h2o.featurestore.api.v1.TransformationType\x12\x14\n\x0cmd5_checksum\x18\x02 \x01(\t\"\xd5\x01\n$GenerateTransformationUploadResponse\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12^\n\x07headers\x18\x03 \x03(\x0b\x32M.ai.h2o.featurestore.api.v1.GenerateTransformationUploadResponse.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"@\n\x17ListProjectsPageRequest\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x12\n\npage_token\x18\x02 \x01(\t\"j\n\x18ListProjectsPageResponse\x12\x35\n\x08projects\x18\x01 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"n\n\rSearchRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x12\n\nowned_only\x18\x04 \x01(\x08\x12\x13\n\x0bproject_ids\x18\x05 \x03(\t\"v\n\x14ProjectSearchResults\x12\x45\n\x10listable_project\x18\x01 \x03(\x0b\x32+.ai.h2o.featurestore.api.v1.ListableProject\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8e\x08\n\x12ListableFeatureSet\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0cproject_name\x18\x04 \x01(\t\x12\x39\n\x15last_update_date_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07version\x18\x06 \x01(\t\x12@\n\npermission\x18\x07 \x01(\x0e\x32,.ai.h2o.featurestore.api.v1.ActivePermission\x12\x12\n\nproject_id\x18\x08 \x01(\t\x12\x16\n\x0eversion_change\x18\t \x01(\t\x12\x1a\n\x12time_travel_column\x18\n \x01(\t\x12!\n\x19time_travel_column_format\x18\x0b \x01(\t\x12\x44\n\x10\x66\x65\x61ture_set_type\x18\x0c \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.FeatureSetType\x12\x39\n\x06\x61uthor\x18\r \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x35\n\x11\x63reated_date_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ndeprecated\x18\x0f \x01(\x08\x12\x33\n\x0f\x64\x65precated_date\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04tags\x18\x11 \x03(\t\x12<\n\x0ctime_to_live\x18\x12 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.TimeToLive\x12H\n\x0cspecial_data\x18\x13 \x01(\x0b\x32\x32.ai.h2o.featurestore.api.v1.FeatureSet.SpecialData\x12\x13\n\x0bprimary_key\x18\x14 \x03(\t\x12<\n\x11time_travel_scope\x18\x15 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x0e\n\x06secret\x18\x16 \x01(\x08\x12\x14\n\x0cpartition_by\x18\x17 \x03(\t\x12G\n\x1conline_materialization_scope\x18\x18 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x44\n\x0c\x64\x65rived_from\x18\x19 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformation\x12\x1b\n\x13\x66\x65\x61ture_classifiers\x18\x1a \x03(\t\"\x80\x01\n\x17\x46\x65\x61tureSetSearchResults\x12L\n\x14listable_feature_set\x18\x01 \x03(\x0b\x32..ai.h2o.featurestore.api.v1.ListableFeatureSet\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xde\x01\n\x0fListableFeature\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x19\n\x11\x61nomaly_detection\x18\x04 \x01(\x08\x12=\n\x0c\x66\x65\x61ture_type\x18\x05 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12\x11\n\tdata_type\x18\x06 \x01(\t\x12\x0f\n\x07version\x18\x07 \x01(\t\x12\x12\n\nfeature_id\x18\x08 \x01(\t\"v\n\x14\x46\x65\x61tureSearchResults\x12\x45\n\x10listable_feature\x18\x01 \x03(\x0b\x32+.ai.h2o.featurestore.api.v1.ListableFeature\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"-\n\x13\x46\x65\x61tureSetRequestId\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\"\\\n\x11GetFeatureRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\x12\x12\n\nfeature_id\x18\x03 \x01(\t\"j\n\x18ListFeaturesPageResponse\x12\x35\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"G\n\x0f\x46\x65\x61tureResponse\x12\x34\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\"c\n\x13ListFeaturesRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\"f\n\x14ListFeaturesResponse\x12\x35\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"P\n\x19ListableFeatureSetRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\"j\n\x1aListableFeatureSetResponse\x12L\n\x14listable_feature_set\x18\x01 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.ListableFeatureSet\"\x85\x01\n\x1eSubmitPendingPermissionRequest\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12>\n\npermission\x18\x02 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.PermissionType\x12\x0e\n\x06reason\x18\x03 \x01(\t\"8\n\x1fSubmitPendingPermissionResponse\x12\x15\n\rpermission_id\x18\x01 \x01(\t\"\x81\x01\n\x1aListPermissionsPageRequest\x12<\n\x07\x66ilters\x18\x01 \x03(\x0e\x32+.ai.h2o.featurestore.api.v1.PermissionState\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x88\x01\n#ListProjectsPermissionsPageResponse\x12H\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x37.ai.h2o.featurestore.api.v1.ListableProjectToPermission\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8e\x01\n&ListFeatureSetsPermissionsPageResponse\x12K\n\x07\x65ntries\x18\x01 \x03(\x0b\x32:.ai.h2o.featurestore.api.v1.ListableFeatureSetToPermission\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x97\x01\n\x1bListableProjectToPermission\x12<\n\x07project\x18\x01 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.ListableProject\x12:\n\npermission\x18\x02 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.Permission\"\xa1\x01\n\x1eListableFeatureSetToPermission\x12\x43\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.ListableFeatureSet\x12:\n\npermission\x18\x02 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.Permission\"\xec\x08\n\nPermission\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12?\n\rresource_type\x18\x03 \x01(\x0e\x32(.ai.h2o.featurestore.api.v1.ResourceType\x12>\n\npermission\x18\x04 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.PermissionType\x12\x37\n\x04user\x18\x05 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x17\n\x0f\x63reation_reason\x18\x06 \x01(\t\x12:\n\x05state\x18\x07 \x01(\x0e\x32+.ai.h2o.featurestore.api.v1.PermissionState\x12.\n\ncreated_on\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0elast_update_on\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06\x61\x63tive\x18\n \x01(\x08\x12[\n\x13granted_or_rejected\x18\x0b \x01(\x0b\x32>.ai.h2o.featurestore.api.v1.Permission.GrantedOrRejectedUpdate\x12\x45\n\x07revoked\x18\x0c \x01(\x0b\x32\x34.ai.h2o.featurestore.api.v1.Permission.RevokedUpdate\x12G\n\x08promoted\x18\r \x01(\x0b\x32\x35.ai.h2o.featurestore.api.v1.Permission.PromotedUpdate\x1a\xac\x01\n\x0ePromotedUpdate\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12.\n\nupdated_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12!\n\x19replaced_by_permission_id\x18\x04 \x01(\t\x1a\x88\x01\n\rRevokedUpdate\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12.\n\nupdated_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06reason\x18\x03 \x01(\t\x1a\x92\x01\n\x17GrantedOrRejectedUpdate\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12.\n\nupdated_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06reason\x18\x03 \x01(\t\"@\n\x17RevokePermissionRequest\x12\x15\n\rpermission_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"H\n\x1f\x41pprovePendingPermissionRequest\x12\x15\n\rpermission_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"G\n\x1eRejectPendingPermissionRequest\x12\x15\n\rpermission_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"1\n\x1aGetActivePermissionRequest\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\"_\n\x1bGetActivePermissionResponse\x12@\n\npermission\x18\x01 \x01(\x0e\x32,.ai.h2o.featurestore.api.v1.ActivePermission\"\xb6\x04\n\rScheduledTask\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12;\n\x06source\x18\x06 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocation\x12\x10\n\x08schedule\x18\x07 \x01(\t\x12\x31\n\rnext_run_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tlast_exec\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x05owner\x18\n \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x35\n\x11\x63reated_date_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_date_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\ttask_type\x18\r \x01(\x0e\x32$.ai.h2o.featurestore.api.v1.TaskType\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x0e \x01(\t\x12\x17\n\x0f\x63rone_time_zone\x18\x0f \x01(\t\"\xa0\x02\n\x13ScheduleTaskRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x35\n\x04\x63red\x18\x05 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.Credentials\x12;\n\x06source\x18\x06 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocation\x12\x10\n\x08schedule\x18\x07 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x08 \x01(\t\x12\x17\n\x0f\x63rone_time_zone\x18\t \x01(\t\"Z\n\x19ListScheduledTasksRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"o\n\x1aListScheduledTasksResponse\x12\x38\n\x05tasks\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.ScheduledTask\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\",\n\x0fScheduledTaskId\x12\x19\n\x11scheduled_task_id\x18\x01 \x01(\t\"P\n\x15ScheduledTaskResponse\x12\x37\n\x04task\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.ScheduledTask\"v\n\x1aScheduledTaskUpdateRequest\x12\x19\n\x11scheduled_task_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08schedule\x18\x03 \x01(\t\x12\x16\n\x0eupdated_fields\x18\x04 \x03(\t\"H\n\x11LazyIngestRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\"G\n\x12LazyIngestResponse\x12\x31\n\x06job_id\x18\x01 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.JobId\"O\n\x18GetLazyIngestTaskRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\"c\n\x16TransformationFunction\x12\x15\n\rfunction_name\x18\x01 \x01(\t\x12\x1d\n\x15supported_input_types\x18\x02 \x03(\t\x12\x13\n\x0boutput_type\x18\x03 \x01(\t\"$\n\"ListTransformationFunctionsRequest\"{\n#ListTransformationFunctionsResponse\x12T\n\x18transformation_functions\x18\x01 \x03(\x0b\x32\x32.ai.h2o.featurestore.api.v1.TransformationFunction\"H\n GetTransformationFunctionRequest\x12$\n\x1ctransformation_function_name\x18\x01 \x01(\t\"x\n!GetTransformationFunctionResponse\x12S\n\x17transformation_function\x18\x01 \x01(\x0b\x32\x32.ai.h2o.featurestore.api.v1.TransformationFunction\"\xda\x01\n\x14UpdateProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0e\n\x06locked\x18\x02 \x01(\x08\x12\x0e\n\x06secret\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12,\n\x0b\x63ustom_data\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12K\n\x10\x66ields_to_update\x18\x06 \x03(\x0e\x32\x31.ai.h2o.featurestore.api.v1.UpdatableProjectField\"\xbc\x07\n\x17UpdateFeatureSetRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x1b\n\x13\x64\x61ta_source_domains\x18\x04 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x38\n\x04type\x18\x06 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.FeatureSetType\x12\x12\n\ndeprecated\x18\x07 \x01(\x08\x12\x18\n\x10process_interval\x18\x08 \x01(\x05\x12N\n\x15process_interval_unit\x18\t \x01(\x0e\x32/.ai.h2o.featurestore.api.v1.ProcessIntervalUnit\x12\x0e\n\x06secret\x18\n \x01(\x08\x12%\n\x1dtime_to_live_offline_interval\x18\x0b \x01(\r\x12\x62\n\"time_to_live_offline_interval_unit\x18\x0c \x01(\x0e\x32\x36.ai.h2o.featurestore.api.v1.Offline.TimeToLiveInterval\x12$\n\x1ctime_to_live_online_interval\x18\r \x01(\r\x12`\n!time_to_live_online_interval_unit\x18\x0e \x01(\x0e\x32\x35.ai.h2o.featurestore.api.v1.Online.TimeToLiveInterval\x12\x16\n\x0elegal_approved\x18\x0f \x01(\x08\x12\x1c\n\x14legal_approved_notes\x18\x10 \x01(\t\x12\r\n\x05state\x18\x11 \x01(\t\x12\x0c\n\x04\x66low\x18\x12 \x01(\t\x12\x18\n\x10\x61pplication_name\x18\x13 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x14 \x01(\t\x12,\n\x0b\x63ustom_data\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x18\n\x10online_namespace\x18\x16 \x01(\t\x12\x14\n\x0conline_topic\x18\x17 \x01(\t\x12\x1e\n\x16online_connection_type\x18\x18 \x01(\t\x12N\n\x10\x66ields_to_update\x18\x19 \x03(\x0e\x32\x34.ai.h2o.featurestore.api.v1.UpdatableFeatureSetField\"\x8b\x03\n\x14UpdateFeatureRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\x12\x12\n\nfeature_id\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x35\n\x04type\x18\x05 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12\x12\n\nimportance\x18\x06 \x01(\x01\x12,\n\x0b\x63ustom_data\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x0f\n\x07special\x18\t \x01(\t\x12\x19\n\x11\x61nomaly_detection\x18\n \x01(\x08\x12\x13\n\x0b\x63lassifiers\x18\x0b \x03(\t\x12K\n\x10\x66ields_to_update\x18\x0c \x03(\x0e\x32\x31.ai.h2o.featurestore.api.v1.UpdatableFeatureField\"\'\n\x10GetOwnersRequest\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\"N\n\x11GetOwnersResponse\x12\x39\n\x06owners\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\"\xe5\x02\n\x0f\x42\x61\x63kfillOptions\x12-\n\tfrom_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x66rom_version\x18\x03 \x01(\t\x12O\n\x0espark_pipeline\x18\x04 \x01(\x0b\x32\x37.ai.h2o.featurestore.api.v1.SparkPipelineTransformation\x12X\n\x0f\x66\x65\x61ture_mapping\x18\x05 \x03(\x0b\x32?.ai.h2o.featurestore.api.v1.BackfillOptions.FeatureMappingEntry\x1a\x35\n\x13\x46\x65\x61tureMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"W\n\x10\x42\x61\x63kfillResponse\x12\x43\n\x0fingest_response\x18\x01 \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.IngestResponse*\x97\x02\n\x07JobType\x12\x0b\n\x07Unknown\x10\x00\x12\n\n\x06Ingest\x10\x01\x12\x0c\n\x08Retrieve\x10\x02\x12\x11\n\rExtractSchema\x10\x03\x12\x0b\n\x07Preview\x10\x04\x12\x15\n\x11\x43omputeStatistics\x10\x05\x12\n\n\x06Revert\x10\x06\x12\x19\n\x15MaterializationOnline\x10\x07\x12$\n ComputeRecommendationClassifiers\x10\x08\x12\x13\n\x0f\x43reateMLDataset\x10\t\x12\x1e\n\x1a\x46\x65\x61tureViewRetrieveAsLinks\x10\n\x12\x1e\n\x1a\x46\x65\x61tureViewRetrieveAsSpark\x10\x0b\x12\x0c\n\x08\x42\x61\x63kfill\x10\x0c*X\n\x0ePermissionType\x12\t\n\x05Owner\x10\x00\x12\n\n\x06\x45\x64itor\x10\x01\x12\x0c\n\x08\x43onsumer\x10\x02\x12\x15\n\x11SensitiveConsumer\x10\x03\x12\n\n\x06Viewer\x10\x04*\xd1\x01\n\x10\x41\x63tivePermission\x12\x1a\n\x16\x41\x43TIVE_PERMISSION_NONE\x10\x00\x12\x1b\n\x17\x41\x43TIVE_PERMISSION_OWNER\x10\x01\x12\x1c\n\x18\x41\x43TIVE_PERMISSION_EDITOR\x10\x02\x12\x1e\n\x1a\x41\x43TIVE_PERMISSION_CONSUMER\x10\x03\x12(\n$ACTIVE_PERMISSION_SENSITIVE_CONSUMER\x10\x04\x12\x1c\n\x18\x41\x43TIVE_PERMISSION_VIEWER\x10\x05*\xfc\x01\n\x15\x46\x65\x61tureFilterOperator\x12#\n\x1f\x46\x45\x41TURE_FILTER_OPERATOR_UNKNOWN\x10\x00\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_EQ\x10\x01\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_LT\x10\x02\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_LE\x10\x03\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_GT\x10\x04\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_GE\x10\x05\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_NE\x10\x06*\x94\x01\n\x1a\x46\x65\x61tureFilterLogicOperator\x12)\n%FEATURE_FILTER_LOGIC_OPERATOR_UNKNOWN\x10\x00\x12%\n!FEATURE_FILTER_LOGIC_OPERATOR_AND\x10\x01\x12$\n FEATURE_FILTER_LOGIC_OPERATOR_OR\x10\x02*\x96\x01\n\x0f\x46\x65\x61tureDataType\x12\x0b\n\x07TinyInt\x10\x00\x12\x0c\n\x08SmallInt\x10\x01\x12\n\n\x06\x42igInt\x10\x02\x12\x07\n\x03Int\x10\x03\x12\t\n\x05\x46loat\x10\x04\x12\n\n\x06\x44ouble\x10\x05\x12\n\n\x06String\x10\x06\x12\n\n\x06\x42inary\x10\x07\x12\x0b\n\x07\x42oolean\x10\x08\x12\x08\n\x04\x44\x61te\x10\t\x12\r\n\tTimestamp\x10\n*q\n\x13ProcessIntervalUnit\x12\r\n\tUNDEFINED\x10\x00\x12\t\n\x05HOURS\x10\x01\x12\n\n\x06MONTHS\x10\x02\x12\x08\n\x04\x44\x41YS\x10\x03\x12\x0b\n\x07MINUTES\x10\x04\x12\x0b\n\x07SECONDS\x10\x05\x12\x10\n\x0cMILLISECONDS\x10\x06*h\n\x12TransformationType\x12\x19\n\x15TransformationUnknown\x10\x00\x12\x16\n\x12TransformationMojo\x10\x01\x12\x1f\n\x1bTransformationSparkPipeline\x10\x02*,\n\x0cResourceType\x12\x0b\n\x07PROJECT\x10\x00\x12\x0f\n\x0b\x46\x45\x41TURE_SET\x10\x01*T\n\x0fPermissionState\x12\x0b\n\x07PENDING\x10\x00\x12\x0b\n\x07GRANTED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02\x12\x0b\n\x07REVOKED\x10\x03\x12\x0c\n\x08PROMOTED\x10\x04*\'\n\x08TaskType\x12\n\n\x06INGEST\x10\x00\x12\x0f\n\x0bLAZY_INGEST\x10\x01*\x8a\x01\n\x15UpdatableProjectField\x12\x17\n\x13PROJECT_UNSPECIFIED\x10\x00\x12\x12\n\x0ePROJECT_LOCKED\x10\x01\x12\x12\n\x0ePROJECT_SECRET\x10\x02\x12\x17\n\x13PROJECT_DESCRIPTION\x10\x03\x12\x17\n\x13PROJECT_CUSTOM_DATA\x10\x04*\xf1\x05\n\x18UpdatableFeatureSetField\x12\x1b\n\x17\x46\x45\x41TURE_SET_UNSPECIFIED\x10\x00\x12\x14\n\x10\x46\x45\x41TURE_SET_TAGS\x10\x01\x12#\n\x1f\x46\x45\x41TURE_SET_DATA_SOURCE_DOMAINS\x10\x02\x12\x1b\n\x17\x46\x45\x41TURE_SET_DESCRIPTION\x10\x03\x12\x14\n\x10\x46\x45\x41TURE_SET_TYPE\x10\x04\x12 \n\x1c\x46\x45\x41TURE_SET_APPLICATION_NAME\x10\x05\x12\x1e\n\x1a\x46\x45\x41TURE_SET_APPLICATION_ID\x10\x06\x12\x1a\n\x16\x46\x45\x41TURE_SET_DEPRECATED\x10\x07\x12 \n\x1c\x46\x45\x41TURE_SET_PROCESS_INTERVAL\x10\x08\x12%\n!FEATURE_SET_PROCESS_INTERVAL_UNIT\x10\t\x12\x14\n\x10\x46\x45\x41TURE_SET_FLOW\x10\n\x12\x15\n\x11\x46\x45\x41TURE_SET_STATE\x10\x0b\x12\x16\n\x12\x46\x45\x41TURE_SET_SECRET\x10\x0c\x12\x1b\n\x17\x46\x45\x41TURE_SET_TTL_OFFLINE\x10\r\x12$\n FEATURE_SET_TTL_OFFLINE_INTERVAL\x10\x0e\x12\x1a\n\x16\x46\x45\x41TURE_SET_TTL_ONLINE\x10\x0f\x12#\n\x1f\x46\x45\x41TURE_SET_TTL_ONLINE_INTERVAL\x10\x10\x12\x1b\n\x17\x46\x45\x41TURE_SET_CUSTOM_DATA\x10\x11\x12+\n\'FEATURE_SET_SPECIAL_DATA_LEGAL_APPROVED\x10\x12\x12(\n$FEATURE_SET_SPECIAL_DATA_LEGAL_NOTES\x10\x13\x12 \n\x1c\x46\x45\x41TURE_SET_ONLINE_NAMESPACE\x10\x14\x12\x1c\n\x18\x46\x45\x41TURE_SET_ONLINE_TOPIC\x10\x15\x12&\n\"FEATURE_SET_ONLINE_CONNECTION_TYPE\x10\x16*\xed\x01\n\x15UpdatableFeatureField\x12\x17\n\x13\x46\x45\x41TURE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x46\x45\x41TURE_STATUS\x10\x01\x12\x10\n\x0c\x46\x45\x41TURE_TYPE\x10\x02\x12\x16\n\x12\x46\x45\x41TURE_IMPORTANCE\x10\x03\x12\x17\n\x13\x46\x45\x41TURE_CUSTOM_DATA\x10\x04\x12\x17\n\x13\x46\x45\x41TURE_DESCRIPTION\x10\x05\x12\x13\n\x0f\x46\x45\x41TURE_SPECIAL\x10\x06\x12\x1d\n\x19\x46\x45\x41TURE_ANOMALY_DETECTION\x10\x07\x12\x17\n\x13\x46\x45\x41TURE_CLASSIFIERS\x10\x08\x32\xad\xc5\x01\n\x0b\x43oreService\x12{\n\x08ListJobs\x12+.ai.h2o.featurestore.api.v1.ListJobsRequest\x1a,.ai.h2o.featurestore.api.v1.ListJobsResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/api/v1/jobs\x12k\n\x06GetJob\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x1f.ai.h2o.featurestore.api.v1.Job\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/api/v1/jobs/{job_id}\x12\x95\x01\n\x0eGetJobProgress\x12,.ai.h2o.featurestore.api.v1.JobProgressInput\x1a-.ai.h2o.featurestore.api.v1.JobProgressOutput\"&\x82\xd3\xe4\x93\x02 \x12\x1e/api/v1/jobs/{job_id}/progress\x12\x9c\x01\n\x15StartExtractSchemaJob\x12\x38.ai.h2o.featurestore.api.v1.StartExtractSchemaJobRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"&\x82\xd3\xe4\x93\x02 \"\x1b/api/v1/jobs/extract-schema:\x01*\x12\x9f\x01\n\x19GetExtractSchemaJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x31.ai.h2o.featurestore.api.v1.ExtractSchemaResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/jobs/extract-schema/{job_id}\x12\x87\x01\n\x0eStartIngestJob\x12\x31.ai.h2o.featurestore.api.v1.StartIngestJobRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/api/v1/ingest/start:\x01*\x12\x85\x01\n\x12GetIngestJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a*.ai.h2o.featurestore.api.v1.IngestResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/api/v1/ingests/{job_id}\x12\x8d\x01\n\x17StartRetrieveAsLinksJob\x12+.ai.h2o.featurestore.api.v1.RetrieveRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/api/v1/ingest/retrieve:\x01*\x12\x9f\x01\n\x1bGetRetrieveAsLinksJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x33.ai.h2o.featurestore.api.v1.RetrieveAsLinksResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /api/v1/ingest/retrieve/{job_id}\x12\x9d\x01\n\x0fRetrieveAsSpark\x12+.ai.h2o.featurestore.api.v1.RetrieveRequest\x1a\x33.ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse\"(\x82\xd3\xe4\x93\x02\"\"\x1d/api/v1/ingest/retrieve/spark:\x01*\x12\x82\x01\n\x0fStartPreviewJob\x12*.ai.h2o.featurestore.api.v1.PreviewRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/v1/preview/start:\x01*\x12\xc0\x01\n\x19GetIngestWriteCredentials\x12\x38.ai.h2o.featurestore.api.v1.IngestWriteCredentialRequest\x1a\x39.ai.h2o.featurestore.api.v1.IngestWriteCredentialResponse\".\x82\xd3\xe4\x93\x02(\x12&/api/v1/ingest/credential/{session_id}\x12\x94\x01\n\x14StartRevertIngestJob\x12\x37.ai.h2o.featurestore.api.v1.StartRevertIngestJobRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/v1/ingest/revert:\x01*\x12}\n\x18GetRevertIngestJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 \x12\x1e/api/v1/ingest/revert/{job_id}\x12\xb5\x01\n\x17HasPermissionToRetrieve\x12:.ai.h2o.featurestore.api.v1.HasPermissionToRetrieveRequest\x1a;.ai.h2o.featurestore.api.v1.HasPermissionToRetrieveResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1/ingest/permission\x12\xa5\x01\n\x12RegisterFeatureSet\x12\x35.ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"(\x82\xd3\xe4\x93\x02\"\"\x1d/api/v1/feature-sets/register:\x01*\x12\xb4\x01\n\x1a\x43reateNewFeatureSetVersion\x12=.ai.h2o.featurestore.api.v1.CreateNewFeatureSetVersionRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/api/v1/feature-sets/version:\x01*\x12\x80\x01\n\x15GetOnlineRetrieveMeta\x12\x16.google.protobuf.Empty\x1a..ai.h2o.featurestore.api.v1.OnlineRetrieveMeta\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/online-retrieve\x12m\n\nGetVersion\x12\x16.google.protobuf.Empty\x1a..ai.h2o.featurestore.api.v1.GetVersionResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/api/v1/version\x12\x91\x01\n\rGetFeatureSet\x12\x30.ai.h2o.featurestore.api.v1.GetFeatureSetRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/api/v1/feature-set:\x01*\x12\xa2\x01\n\x11GetFeatureSetById\x12/.ai.h2o.featurestore.api.v1.FeatureSetRequestId\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/feature-set/{feature_set_id}\x12\xc6\x01\n&GetFeatureSetsLastMinorForCurrentMajor\x12I.ai.h2o.featurestore.api.v1.GetFeatureSetsLastMinorForCurrentMajorRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1/feature-sets-last\x12\xb5\x01\n\x16ListFeatureSetVersions\x12\x39.ai.h2o.featurestore.api.v1.ListFeatureSetsVersionRequest\x1a:.ai.h2o.featurestore.api.v1.ListFeatureSetVersionsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1/feature-sets/version\x12\x80\x01\n\x10\x44\x65leteFeatureSet\x12\x33.ai.h2o.featurestore.api.v1.DeleteFeatureSetRequest\x1a\x16.google.protobuf.Empty\"\x1f\x82\xd3\xe4\x93\x02\x19*\x14/api/v1/feature-sets:\x01*\x12\xa4\x01\n\x13ListFeatureSetsPage\x12\x36.ai.h2o.featurestore.api.v1.ListFeatureSetsPageRequest\x1a\x37.ai.h2o.featurestore.api.v1.ListFeatureSetsPageResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1/feature-sets\x12\x98\x01\n\x10\x46\x65\x61tureSetExists\x12\x33.ai.h2o.featurestore.api.v1.FeatureSetExistsRequest\x1a*.ai.h2o.featurestore.api.v1.ExistsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/api/v1/feature-sets/exists\x12\x9d\x01\n\x10GetIngestHistory\x12\x33.ai.h2o.featurestore.api.v1.GetIngestHistoryRequest\x1a\x34.ai.h2o.featurestore.api.v1.GetIngestHistoryResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/api/v1/ingest/history\x12\xa9\x01\n\x1aUpdateFeatureSetPrimaryKey\x12\x43.ai.h2o.featurestore.api.v1.FeatureSetStringArrayFieldUpdateRequest\x1a\x16.google.protobuf.Empty\".\x88\x02\x01\x82\xd3\xe4\x93\x02%\x1a /api/v1/feature-sets/primary-key:\x01*\x12\x9c\x01\n\x14UpdateFeatureSetTags\x12\x43.ai.h2o.featurestore.api.v1.FeatureSetStringArrayFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"\'\x88\x02\x01\x82\xd3\xe4\x93\x02\x1e\x1a\x19/api/v1/feature-sets/tags:\x01*\x12\xb8\x01\n!UpdateFeatureSetDataSourceDomains\x12\x43.ai.h2o.featurestore.api.v1.FeatureSetStringArrayFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"6\x88\x02\x01\x82\xd3\xe4\x93\x02-\x1a(/api/v1/feature-sets/data-source-domains:\x01*\x12\xa5\x01\n\x1bUpdateFeatureSetDescription\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\".\x88\x02\x01\x82\xd3\xe4\x93\x02%\x1a /api/v1/feature-sets/description:\x01*\x12\x90\x01\n\x14UpdateFeatureSetType\x12\x37.ai.h2o.featurestore.api.v1.FeatureSetTypeUpdateRequest\x1a\x16.google.protobuf.Empty\"\'\x88\x02\x01\x82\xd3\xe4\x93\x02\x1e\x1a\x19/api/v1/feature-sets/type:\x01*\x12\x97\x01\n\x15UpdateFeatureSetOwner\x12<.ai.h2o.featurestore.api.v1.FeatureSetUserFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"(\x88\x02\x01\x82\xd3\xe4\x93\x02\x1f\x1a\x1a/api/v1/feature-sets/owner:\x01*\x12\xae\x01\n\x1fUpdateFeatureSetApplicationName\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"3\x88\x02\x01\x82\xd3\xe4\x93\x02*\x1a%/api/v1/feature-sets/application-name:\x01*\x12\xaa\x01\n\x1dUpdateFeatureSetApplicationId\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"1\x88\x02\x01\x82\xd3\xe4\x93\x02(\x1a#/api/v1/feature-sets/application-id:\x01*\x12\xa4\x01\n\x1aUpdateFeatureSetDeprecated\x12?.ai.h2o.featurestore.api.v1.FeatureSetBooleanFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"-\x88\x02\x01\x82\xd3\xe4\x93\x02$\x1a\x1f/api/v1/feature-sets/deprecated:\x01*\x12\xab\x01\n\x1fUpdateFeatureSetProcessInterval\x12;.ai.h2o.featurestore.api.v1.FeatureSetIntFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"3\x88\x02\x01\x82\xd3\xe4\x93\x02*\x1a%/api/v1/feature-sets/process-interval:\x01*\x12\xbf\x01\n#UpdateFeatureSetProcessIntervalUnit\x12\x46.ai.h2o.featurestore.api.v1.FeatureSetProcessIntervalUnitUpdateRequest\x1a\x16.google.protobuf.Empty\"8\x88\x02\x01\x82\xd3\xe4\x93\x02/\x1a*/api/v1/feature-sets/process-interval-unit:\x01*\x12\x97\x01\n\x14UpdateFeatureSetFlow\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"\'\x88\x02\x01\x82\xd3\xe4\x93\x02\x1e\x1a\x19/api/v1/feature-sets/flow:\x01*\x12\x99\x01\n\x15UpdateFeatureSetState\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"(\x88\x02\x01\x82\xd3\xe4\x93\x02\x1f\x1a\x1a/api/v1/feature-sets/state:\x01*\x12\x9c\x01\n\x16UpdateFeatureSetSecret\x12?.ai.h2o.featurestore.api.v1.FeatureSetBooleanFieldUpdateRequest\x1a\x16.google.protobuf.Empty\")\x88\x02\x01\x82\xd3\xe4\x93\x02 \x1a\x1b/api/v1/feature-sets/secret:\x01*\x12\xa3\x01\n\x1aUpdateFeatureSetCustomData\x12=.ai.h2o.featurestore.api.v1.FeatureSetCustomDataUpdateRequest\x1a\x16.google.protobuf.Empty\".\x88\x02\x01\x82\xd3\xe4\x93\x02%\x1a /api/v1/feature-sets/custom-data:\x01*\x12\xaf\x01\n\x1fUpdateTimeToLiveOfflineInterval\x12;.ai.h2o.featurestore.api.v1.FeatureSetIntFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"7\x88\x02\x01\x82\xd3\xe4\x93\x02.\x1a)/api/v1/feature-sets/time-to-live-offline:\x01*\x12\xcd\x01\n#UpdateTimeToLiveOfflineIntervalUnit\x12P.ai.h2o.featurestore.api.v1.FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest\x1a\x16.google.protobuf.Empty\"<\x88\x02\x01\x82\xd3\xe4\x93\x02\x33\x1a./api/v1/feature-sets/time-to-live-offline-unit:\x01*\x12\xad\x01\n\x1eUpdateTimeToLiveOnlineInterval\x12;.ai.h2o.featurestore.api.v1.FeatureSetIntFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"6\x88\x02\x01\x82\xd3\xe4\x93\x02-\x1a(/api/v1/feature-sets/time-to-live-online:\x01*\x12\xca\x01\n\"UpdateTimeToLiveOnlineIntervalUnit\x12O.ai.h2o.featurestore.api.v1.FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest\x1a\x16.google.protobuf.Empty\";\x88\x02\x01\x82\xd3\xe4\x93\x02\x32\x1a-/api/v1/feature-sets/time-to-live-online-unit:\x01*\x12\xae\x01\n\x1fUpdateFeatureSetOnlineNamespace\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"3\x88\x02\x01\x82\xd3\xe4\x93\x02*\x1a%/api/v1/feature-sets/online-namespace:\x01*\x12\xa6\x01\n\x1bUpdateFeatureSetOnlineTopic\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"/\x88\x02\x01\x82\xd3\xe4\x93\x02&\x1a!/api/v1/feature-sets/online-topic:\x01*\x12\xb9\x01\n$UpdateFeatureSetOnlineConnectionType\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"9\x88\x02\x01\x82\xd3\xe4\x93\x02\x30\x1a+/api/v1/feature-sets/online-connection-type:\x01*\x12\xab\x01\n\x1dUpdateFeatureSetLegalApproved\x12?.ai.h2o.featurestore.api.v1.FeatureSetBooleanFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"1\x88\x02\x01\x82\xd3\xe4\x93\x02(\x1a#/api/v1/feature-sets/legal-approved:\x01*\x12\xb5\x01\n\"UpdateFeatureSetLegalApprovedNotes\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"7\x88\x02\x01\x82\xd3\xe4\x93\x02.\x1a)/api/v1/feature-sets/legal-approved-notes:\x01*\x12\x9b\x01\n\x13UpdateFeatureStatus\x12;.ai.h2o.featurestore.api.v1.FeatureStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"/\x82\xd3\xe4\x93\x02)\x1a$/api/v1/feature-sets/features/status:\x01*\x12\x90\x01\n\x11UpdateFeatureType\x12\x34.ai.h2o.featurestore.api.v1.FeatureTypeUpdateRequest\x1a\x16.google.protobuf.Empty\"-\x82\xd3\xe4\x93\x02\'\x1a\"/api/v1/feature-sets/features/type:\x01*\x12\xa3\x01\n\x17UpdateFeatureCustomData\x12:.ai.h2o.featurestore.api.v1.FeatureCustomDataUpdateRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.\x1a)/api/v1/feature-sets/features/custom-data:\x01*\x12\xa3\x01\n\x17UpdateFeatureImportance\x12;.ai.h2o.featurestore.api.v1.FeatureDoubleFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"3\x82\xd3\xe4\x93\x02-\x1a(/api/v1/feature-sets/features/importance:\x01*\x12\xa5\x01\n\x18UpdateFeatureDescription\x12;.ai.h2o.featurestore.api.v1.FeatureStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.\x1a)/api/v1/feature-sets/features/description:\x01*\x12\x9d\x01\n\x14UpdateFeatureSpecial\x12;.ai.h2o.featurestore.api.v1.FeatureStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02*\x1a%/api/v1/feature-sets/features/special:\x01*\x12\xb1\x01\n\x1dUpdateFeatureAnomalyDetection\x12<.ai.h2o.featurestore.api.v1.FeatureBooleanFieldUpdateRequest\x1a\x16.google.protobuf.Empty\":\x82\xd3\xe4\x93\x02\x34\x1a//api/v1/feature-sets/features/anomaly-detection:\x01*\x12\xaa\x01\n\x18UpdateFeatureClassifiers\x12@.ai.h2o.featurestore.api.v1.FeatureStringArrayFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.\x1a)/api/v1/feature-sets/features/classifiers:\x01*\x12\xdf\x01\n\x1cIsFeatureSetSchemaCompatible\x12@.ai.h2o.featurestore.api.v1.FeatureSetSchemaCompatibilityRequest\x1a\x41.ai.h2o.featurestore.api.v1.FeatureSetSchemaCompatibilityResponse\":\x82\xd3\xe4\x93\x02\x34\"//api/v1/feature-sets/features/schema-compatible:\x01*\x12\xba\x01\n\x15\x46\x65\x61tureSetSchemaPatch\x12\x38.ai.h2o.featurestore.api.v1.FeatureSetSchemaPatchRequest\x1a\x39.ai.h2o.featurestore.api.v1.FeatureSetSchemaPatchResponse\",\x82\xd3\xe4\x93\x02&\"!/api/v1/feature-sets/schema-patch:\x01*\x12\xc0\x01\n\x14GetFeatureSetPreview\x12\x37.ai.h2o.featurestore.api.v1.GetFeatureSetPreviewRequest\x1a\x38.ai.h2o.featurestore.api.v1.GetFeatureSetPreviewResponse\"5\x82\xd3\xe4\x93\x02/\x12-/api/v1/feature-set-previews/{feature_set_id}\x12\xaf\x01\n\x10UpdateFeatureSet\x12\x33.ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest\x1a\x34.ai.h2o.featurestore.api.v1.UpdateFeatureSetResponse\"0\x82\xd3\xe4\x93\x02*\x1a%/api/v1/feature-sets/{feature_set_id}:\x01*\x12\x9c\x01\n\x11\x43reateFeatureView\x12\x34.ai.h2o.featurestore.api.v1.CreateFeatureViewRequest\x1a/.ai.h2o.featurestore.api.v1.FeatureViewResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/v1/feature-views:\x01*\x12\xc5\x01\n\x11UpdateFeatureView\x12\x34.ai.h2o.featurestore.api.v1.UpdateFeatureViewRequest\x1a/.ai.h2o.featurestore.api.v1.FeatureViewResponse\"I\x82\xd3\xe4\x93\x02\x43\x1a>/api/v1/feature-views/{feature_view_id}/{feature_view_version}:\x01*\x12\xb0\x01\n\x0eGetFeatureView\x12\x31.ai.h2o.featurestore.api.v1.GetFeatureViewRequest\x1a/.ai.h2o.featurestore.api.v1.FeatureViewResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/api/v1/projects/{project_id}/feature-views/{name}\x12\x9c\x01\n\x10ListFeatureViews\x12\x33.ai.h2o.featurestore.api.v1.ListFeatureViewsRequest\x1a\x34.ai.h2o.featurestore.api.v1.ListFeatureViewsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/api/v1/feature-views\x12\xb0\x01\n\x1b\x43reateFeatureViewNewVersion\x12>.ai.h2o.featurestore.api.v1.CreateFeatureViewNewVersionRequest\x1a/.ai.h2o.featurestore.api.v1.FeatureViewResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/v1/feature-views:\x01*\x12\xd7\x01\n\"StartRetrieveFeatureViewAsSparkJob\x12=.ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"O\x82\xd3\xe4\x93\x02I\"D/api/v1/feature-views/{feature_view_id}/{feature_view_version}/spark:\x01*\x12\xb9\x01\n&GetRetrieveFeatureViewAsSparkJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a>.ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/feature-views/spark/{job_id}\x12\xd9\x01\n\"StartRetrieveFeatureViewAsLinksJob\x12?.ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsAsLinksRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"O\x82\xd3\xe4\x93\x02I\"D/api/v1/feature-views/{feature_view_id}/{feature_view_version}/links:\x01*\x12\xbb\x01\n&GetRetrieveFeatureViewAsLinksJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a@.ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsAsLinksResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/feature-views/links/{job_id}\x12\x92\x01\n\x11\x44\x65leteFeatureView\x12\x34.ai.h2o.featurestore.api.v1.DeleteFeatureViewRequest\x1a\x16.google.protobuf.Empty\"/\x82\xd3\xe4\x93\x02)*\'/api/v1/feature-views/{feature_view_id}\x12\x9a\x01\n\x0f\x43reateMLDataset\x12\x32.ai.h2o.featurestore.api.v1.CreateMLDatasetRequest\x1a\x33.ai.h2o.featurestore.api.v1.CreateMLDatasetResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/api/v1/ml-datasets:\x01*\x12\x8f\x01\n\x1dGetMLDatasetCreationJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a%.ai.h2o.featurestore.api.v1.MLDataset\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1/ml-datasets/{job_id}\x12\x9c\x01\n\x0fUpdateMLDataset\x12\x32.ai.h2o.featurestore.api.v1.UpdateMLDatasetRequest\x1a%.ai.h2o.featurestore.api.v1.MLDataset\".\x82\xd3\xe4\x93\x02(\x1a#/api/v1/ml-datasets/{ml_dataset_id}:\x01*\x12\x8a\x01\n\x0f\x44\x65leteMLDataset\x12\x32.ai.h2o.featurestore.api.v1.DeleteMLDatasetRequest\x1a\x16.google.protobuf.Empty\"+\x82\xd3\xe4\x93\x02%*#/api/v1/ml-datasets/{ml_dataset_id}\x12\x93\x01\n\x0cGetMLDataset\x12/.ai.h2o.featurestore.api.v1.GetMLDatasetRequest\x1a%.ai.h2o.featurestore.api.v1.MLDataset\"+\x82\xd3\xe4\x93\x02%\x12#/api/v1/ml-datasets/{ml_dataset_id}\x12\x94\x01\n\x0eListMLDatasets\x12\x31.ai.h2o.featurestore.api.v1.ListMLDatasetsRequest\x1a\x32.ai.h2o.featurestore.api.v1.ListMLDatasetsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/api/v1/ml-datasets\x12\xc5\x01\n\x18RetrieveMLDatasetAsSpark\x12;.ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkRequest\x1a<.ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkResponse\".\x82\xd3\xe4\x93\x02(\"#/api/v1/ml-datasets/{ml_dataset_id}:\x01*\x12\xc6\x01\n\x18RetrieveMLDatasetAsLinks\x12=.ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsAsLinksRequest\x1a>.ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsAsLinksResponse\"+\x82\xd3\xe4\x93\x02%\x12#/api/v1/ml-datasets/{ml_dataset_id}\x12\xbd\x01\n\x17RetrieveMLDatasetOnline\x12:.ai.h2o.featurestore.api.v1.RetrieveMLDatasetOnlineRequest\x1a\x32.ai.h2o.featurestore.api.v1.OnlineRetrieveResponse\"2\x82\xd3\xe4\x93\x02,\x12*/api/v1/ml-datasets/{ml_dataset_id}/online\x12\x97\x01\n\x10ListProjectsPage\x12\x33.ai.h2o.featurestore.api.v1.ListProjectsPageRequest\x1a\x34.ai.h2o.featurestore.api.v1.ListProjectsPageResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/api/v1/projects\x12\x91\x01\n\rCreateProject\x12\x30.ai.h2o.featurestore.api.v1.CreateProjectRequest\x1a\x31.ai.h2o.featurestore.api.v1.CreateProjectResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/api/v1/projects:\x01*\x12\x91\x01\n\nGetProject\x12-.ai.h2o.featurestore.api.v1.GetProjectRequest\x1a+.ai.h2o.featurestore.api.v1.ProjectResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/api/v1/projects/{project_name}\x12v\n\rDeleteProject\x12\x30.ai.h2o.featurestore.api.v1.DeleteProjectRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15*\x10/api/v1/projects:\x01*\x12\x83\x01\n\x12GetProjectsDefault\x12\x16.google.protobuf.Empty\x1a\x33.ai.h2o.featurestore.api.v1.ProjectsDefaultResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/api/v1/projects/default\x12\x9b\x01\n\rProjectExists\x12\x30.ai.h2o.featurestore.api.v1.ProjectExistsRequest\x1a*.ai.h2o.featurestore.api.v1.ExistsResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/projects/{project_id}/exists\x12\x9f\x01\n\x13UpdateProjectSecret\x12<.ai.h2o.featurestore.api.v1.ProjectBooleanFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"2\x88\x02\x01\x82\xd3\xe4\x93\x02)\x1a$/api/v1/projects/{project_id}/secret:\x01*\x12\x9f\x01\n\x13UpdateProjectLocked\x12<.ai.h2o.featurestore.api.v1.ProjectBooleanFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"2\x88\x02\x01\x82\xd3\xe4\x93\x02)\x1a$/api/v1/projects/{project_id}/locked:\x01*\x12\x9a\x01\n\x12UpdateProjectOwner\x12\x39.ai.h2o.featurestore.api.v1.ProjectUserFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"1\x88\x02\x01\x82\xd3\xe4\x93\x02(\x1a#/api/v1/projects/{project_id}/owner:\x01*\x12\xa8\x01\n\x18UpdateProjectDescription\x12;.ai.h2o.featurestore.api.v1.ProjectStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"7\x88\x02\x01\x82\xd3\xe4\x93\x02.\x1a)/api/v1/projects/{project_id}/description:\x01*\x12\xa6\x01\n\x17UpdateProjectCustomData\x12:.ai.h2o.featurestore.api.v1.ProjectCustomDataUpdateRequest\x1a\x16.google.protobuf.Empty\"7\x88\x02\x01\x82\xd3\xe4\x93\x02.\x1a)/api/v1/projects/{project_id}/custom-data:\x01*\x12\x9e\x01\n\rUpdateProject\x12\x30.ai.h2o.featurestore.api.v1.UpdateProjectRequest\x1a\x31.ai.h2o.featurestore.api.v1.UpdateProjectResponse\"(\x82\xd3\xe4\x93\x02\"\x1a\x1d/api/v1/projects/{project_id}:\x01*\x12\x91\x01\n\x0eGetAccessToken\x12/.ai.h2o.featurestore.api.v1.RefreshTokenRequest\x1a/.ai.h2o.featurestore.api.v1.AccessTokenResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/api/v1/auth/token:\x01*\x12\x98\x01\n\rGetUserByMail\x12\x30.ai.h2o.featurestore.api.v1.GetUserByMailRequest\x1a\x31.ai.h2o.featurestore.api.v1.GetUserByMailResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/auth/users/{email}\x12k\n\x06Logout\x12).ai.h2o.featurestore.api.v1.LogoutRequest\x1a\x16.google.protobuf.Empty\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/api/v1/auth/logout:\x01*\x12v\n\rGetActiveUser\x12\x16.google.protobuf.Empty\x1a\x31.ai.h2o.featurestore.api.v1.GetActiveUserResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/api/v1/auth/users\x12k\n\x05Login\x12\x16.google.protobuf.Empty\x1a).ai.h2o.featurestore.api.v1.LoginResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/api/v1/auth/login:\x01*0\x01\x12p\n\x0cGetWebConfig\x12\x16.google.protobuf.Empty\x1a\x30.ai.h2o.featurestore.api.v1.GetWebConfigResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/api/v1/config\x12\xb4\x01\n\x17\x41\x64\x64\x46\x65\x61tureSetPermission\x12\x37.ai.h2o.featurestore.api.v1.FeatureSetPermissionRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"0\x82\xd3\xe4\x93\x02*\"%/api/v1/auth/feature-sets/permissions:\x01*\x12\xa7\x01\n\x14\x41\x64\x64ProjectPermission\x12\x34.ai.h2o.featurestore.api.v1.ProjectPermissionRequest\x1a+.ai.h2o.featurestore.api.v1.ProjectResponse\",\x82\xd3\xe4\x93\x02&\"!/api/v1/auth/projects/permissions:\x01*\x12\xb7\x01\n\x1aRemoveFeatureSetPermission\x12\x37.ai.h2o.featurestore.api.v1.FeatureSetPermissionRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"0\x82\xd3\xe4\x93\x02**%/api/v1/auth/feature-sets/permissions:\x01*\x12\xaa\x01\n\x17RemoveProjectPermission\x12\x34.ai.h2o.featurestore.api.v1.ProjectPermissionRequest\x1a+.ai.h2o.featurestore.api.v1.ProjectResponse\",\x82\xd3\xe4\x93\x02&*!/api/v1/auth/projects/permissions:\x01*\x12\xd0\x01\n\x1eSubmitPendingProjectPermission\x12:.ai.h2o.featurestore.api.v1.SubmitPendingPermissionRequest\x1a;.ai.h2o.featurestore.api.v1.SubmitPendingPermissionResponse\"5\x82\xd3\xe4\x93\x02/\"*/api/v1/permissions/projects/{resource_id}:\x01*\x12\xd7\x01\n!SubmitPendingFeatureSetPermission\x12:.ai.h2o.featurestore.api.v1.SubmitPendingPermissionRequest\x1a;.ai.h2o.featurestore.api.v1.SubmitPendingPermissionResponse\"9\x82\xd3\xe4\x93\x02\x33\"./api/v1/permissions/feature-sets/{resource_id}:\x01*\x12\xbb\x01\n\x1aListProjectPermissionsPage\x12\x36.ai.h2o.featurestore.api.v1.ListPermissionsPageRequest\x1a?.ai.h2o.featurestore.api.v1.ListProjectsPermissionsPageResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1/permissions/projects\x12\xc6\x01\n\x1eListFeatureSetsPermissionsPage\x12\x36.ai.h2o.featurestore.api.v1.ListPermissionsPageRequest\x1a\x42.ai.h2o.featurestore.api.v1.ListFeatureSetsPermissionsPageResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /api/v1/permissions/feature-sets\x12\xd0\x01\n$ListManageableProjectPermissionsPage\x12\x36.ai.h2o.featurestore.api.v1.ListPermissionsPageRequest\x1a?.ai.h2o.featurestore.api.v1.ListProjectsPermissionsPageResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/api/v1/permissions/manageable-projects\x12\xdb\x01\n(ListManageableFeatureSetsPermissionsPage\x12\x36.ai.h2o.featurestore.api.v1.ListPermissionsPageRequest\x1a\x42.ai.h2o.featurestore.api.v1.ListFeatureSetsPermissionsPageResponse\"3\x82\xd3\xe4\x93\x02-\x12+/api/v1/permissions/manageable-feature-sets\x12\x98\x01\n\x18\x41pprovePendingPermission\x12;.ai.h2o.featurestore.api.v1.ApprovePendingPermissionRequest\x1a\x16.google.protobuf.Empty\"\'\x82\xd3\xe4\x93\x02!\"\x1c/api/v1/permissions/approval:\x01*\x12\x97\x01\n\x17RejectPendingPermission\x12:.ai.h2o.featurestore.api.v1.RejectPendingPermissionRequest\x1a\x16.google.protobuf.Empty\"(\x82\xd3\xe4\x93\x02\"\"\x1d/api/v1/permissions/rejection:\x01*\x12\x86\x01\n\x10RevokePermission\x12\x33.ai.h2o.featurestore.api.v1.RevokePermissionRequest\x1a\x16.google.protobuf.Empty\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/api/v1/permissions/revoke:\x01*\x12\xc8\x01\n\x1aGetActiveProjectPermission\x12\x36.ai.h2o.featurestore.api.v1.GetActivePermissionRequest\x1a\x37.ai.h2o.featurestore.api.v1.GetActivePermissionResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/api/v1/permissions/projects/{resource_id}/active\x12\xcf\x01\n\x1dGetActiveFeatureSetPermission\x12\x36.ai.h2o.featurestore.api.v1.GetActivePermissionRequest\x1a\x37.ai.h2o.featurestore.api.v1.GetActivePermissionResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/api/v1/permissions/feature-sets/{resource_id}/active\x12\xa9\x01\n\x10GetProjectOwners\x12,.ai.h2o.featurestore.api.v1.GetOwnersRequest\x1a-.ai.h2o.featurestore.api.v1.GetOwnersResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/api/v1/permissions/project/{resource_id}/owners\x12\xb1\x01\n\x13GetFeatureSetOwners\x12,.ai.h2o.featurestore.api.v1.GetOwnersRequest\x1a-.ai.h2o.featurestore.api.v1.GetOwnersResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/api/v1/permissions/feature-sets/{resource_id}/owners\x12u\n\x0bRevokeToken\x12(.ai.h2o.featurestore.api.v1.TokenRequest\x1a\x16.google.protobuf.Empty\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/api/v1/auth/token/revoke:\x01*\x12\x8e\x01\n\rGenerateToken\x12\x30.ai.h2o.featurestore.api.v1.GenerateTokenRequest\x1a,.ai.h2o.featurestore.api.v1.RawTokenResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/api/v1/auth/token:\x01*\x12q\n\nListTokens\x12\x16.google.protobuf.Empty\x1a..ai.h2o.featurestore.api.v1.ListTokensResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/api/v1/auth/tokens\x12\x87\x01\n\x08GetToken\x12(.ai.h2o.featurestore.api.v1.TokenRequest\x1a).ai.h2o.featurestore.api.v1.TokenResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/api/v1/auth/tokens/{token_id}\x12\x98\x01\n\x0eOnlineRetrieve\x12\x31.ai.h2o.featurestore.api.v1.OnlineRetrieveRequest\x1a\x32.ai.h2o.featurestore.api.v1.OnlineRetrieveResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/online-retrieve\x12v\n\x0cOnlineIngest\x12/.ai.h2o.featurestore.api.v1.OnlineIngestRequest\x1a\x16.google.protobuf.Empty\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/api/v1/online-ingest\x12\x9c\x01\n\x1dStartMaterializationOnlineJob\x12=.ai.h2o.featurestore.api.v1.StartMaterializationOnlineRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/api/v1/online:\x01*\x12\xa2\x01\n!GetMaterializationOnlineJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x39.ai.h2o.featurestore.api.v1.MaterializationOnlineResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/online/{job_id}\x12\x87\x01\n\x1dGetComputeStatisticsJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x16.google.protobuf.Empty\"+\x82\xd3\xe4\x93\x02%\x12#/api/v1/compute-statistics/{job_id}\x12\x9b\x01\n,GetComputeRecommendationClassifiersJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02*\x12(/api/v1/compute-recommendations/{job_id}\x12\xc5\x01\n\x1cGenerateTransformationUpload\x12?.ai.h2o.featurestore.api.v1.GenerateTransformationUploadRequest\x1a@.ai.h2o.featurestore.api.v1.GenerateTransformationUploadResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/api/v1/transformations:\x01*\x12\xb3\x01\n\x1dListRecommendationClassifiers\x12\x16.google.protobuf.Empty\x1a@.ai.h2o.featurestore.api.v1.ListRecommendationClassifierResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/api/v1/feature-sets/recommendations-classifiers\x12\xb8\x01\n\x1e\x43reateRecommendationClassifier\x12\x41.ai.h2o.featurestore.api.v1.CreateRecommendationClassifierRequest\x1a\x16.google.protobuf.Empty\";\x82\xd3\xe4\x93\x02\x35\"0/api/v1/feature-sets/recommendations-classifiers:\x01*\x12\xbf\x01\n\x1eUpdateRecommendationClassifier\x12\x41.ai.h2o.featurestore.api.v1.UpdateRecommendationClassifierRequest\x1a\x16.google.protobuf.Empty\"B\x82\xd3\xe4\x93\x02<\x1a\x37/api/v1/feature-sets/recommendations-classifiers/{name}:\x01*\x12\xc7\x01\n\x1e\x44\x65leteRecommendationClassifier\x12\x41.ai.h2o.featurestore.api.v1.DeleteRecommendationClassifierRequest\x1a\x16.google.protobuf.Empty\"J\x82\xd3\xe4\x93\x02\x44*B/api/v1/feature-sets/recommendations-classifiers/{classifier_name}\x12\xaf\x01\n\x12GetRecommendations\x12\x34.ai.h2o.featurestore.api.v1.GetRecommendationRequest\x1a\x35.ai.h2o.featurestore.api.v1.GetRecommendationResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/feature-sets/recommendations\x12p\n\x0cGetDashboard\x12\x16.google.protobuf.Empty\x1a-.ai.h2o.featurestore.api.v1.DashboardResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/api/v1/dashboard\x12\x8e\x01\n\x0eSearchProjects\x12).ai.h2o.featurestore.api.v1.SearchRequest\x1a\x30.ai.h2o.featurestore.api.v1.ProjectSearchResults\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/search/projects\x12\x98\x01\n\x11SearchFeatureSets\x12).ai.h2o.featurestore.api.v1.SearchRequest\x1a\x33.ai.h2o.featurestore.api.v1.FeatureSetSearchResults\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/api/v1/search/feature-sets\x12\x8d\x01\n\x0eSearchFeatures\x12).ai.h2o.featurestore.api.v1.SearchRequest\x1a\x30.ai.h2o.featurestore.api.v1.FeatureSearchResults\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/api/v1/search/feature\x12\xad\x01\n\nGetFeature\x12-.ai.h2o.featurestore.api.v1.GetFeatureRequest\x1a+.ai.h2o.featurestore.api.v1.FeatureResponse\"C\x82\xd3\xe4\x93\x02=\x12;/api/v1/feature-sets/{feature_set_id}/features/{feature_id}\x12\xa8\x01\n\x0bListFeature\x12/.ai.h2o.featurestore.api.v1.ListFeaturesRequest\x1a\x30.ai.h2o.featurestore.api.v1.ListFeaturesResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./api/v1/feature-sets/{feature_set_id}/features\x12\xbc\x01\n\rUpdateFeature\x12\x30.ai.h2o.featurestore.api.v1.UpdateFeatureRequest\x1a\x31.ai.h2o.featurestore.api.v1.UpdateFeatureResponse\"F\x82\xd3\xe4\x93\x02@\x1a;/api/v1/feature-sets/{feature_set_id}/features/{feature_id}:\x01*\x12\xbe\x01\n\x15GetListableFeatureSet\x12\x35.ai.h2o.featurestore.api.v1.ListableFeatureSetRequest\x1a\x36.ai.h2o.featurestore.api.v1.ListableFeatureSetResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./api/v1/listable-feature-sets/{feature_set_id}\x12\x9f\x01\n\x11ScheduleIngestJob\x12/.ai.h2o.featurestore.api.v1.ScheduleTaskRequest\x1a\x31.ai.h2o.featurestore.api.v1.ScheduledTaskResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/api/v1/schedules/ingestion:\x01*\x12\x9e\x01\n\x12ListScheduledTasks\x12\x35.ai.h2o.featurestore.api.v1.ListScheduledTasksRequest\x1a\x36.ai.h2o.featurestore.api.v1.ListScheduledTasksResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/api/v1/schedules\x12\xa1\x01\n\x10GetScheduledTask\x12+.ai.h2o.featurestore.api.v1.ScheduledTaskId\x1a\x31.ai.h2o.featurestore.api.v1.ScheduledTaskResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/api/v1/schedules/{scheduled_task_id}\x12\x89\x01\n\x13\x44\x65leteScheduledTask\x12+.ai.h2o.featurestore.api.v1.ScheduledTaskId\x1a\x16.google.protobuf.Empty\"-\x82\xd3\xe4\x93\x02\'*%/api/v1/schedules/{scheduled_task_id}\x12\x97\x01\n\x13UpdateScheduledTask\x12\x36.ai.h2o.featurestore.api.v1.ScheduledTaskUpdateRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02*\x1a%/api/v1/schedules/{scheduled_task_id}:\x01*\x12\xa9\x01\n\x16ScheduleLazyIngestTask\x12/.ai.h2o.featurestore.api.v1.ScheduleTaskRequest\x1a\x31.ai.h2o.featurestore.api.v1.ScheduledTaskResponse\"+\x82\xd3\xe4\x93\x02%\" /api/v1/schedules/lazy/ingestion:\x01*\x12\xa4\x01\n\x13StartLazyIngestTask\x12-.ai.h2o.featurestore.api.v1.LazyIngestRequest\x1a..ai.h2o.featurestore.api.v1.LazyIngestResponse\".\x82\xd3\xe4\x93\x02(\x12&/api/v1/schedules/lazy/ingestion/start\x12\xb7\x01\n\x11GetLazyIngestTask\x12\x34.ai.h2o.featurestore.api.v1.GetLazyIngestTaskRequest\x1a\x31.ai.h2o.featurestore.api.v1.ScheduledTaskResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/api/v1/schedules/lazy/ingestion/{feature_set_id}\x12\xc8\x01\n\x1bListTransformationFunctions\x12>.ai.h2o.featurestore.api.v1.ListTransformationFunctionsRequest\x1a?.ai.h2o.featurestore.api.v1.ListTransformationFunctionsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /api/v1/transformation_functions\x12\xe1\x01\n\x19GetTransformationFunction\x12<.ai.h2o.featurestore.api.v1.GetTransformationFunctionRequest\x1a=.ai.h2o.featurestore.api.v1.GetTransformationFunctionResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/api/v1/transformation_functions/{transformation_function_name}\x12\x8a\x01\n\x14GetBackfillJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a,.ai.h2o.featurestore.api.v1.BackfillResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1/backfill/{job_id}B\x14\x42\x10\x43oreServiceProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.featurestore.api.v1.CoreService_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\020CoreServiceProtoP\001'
  _RETRIEVEASSPARKRESPONSE_OPTIONSENTRY._options = None
  _RETRIEVEASSPARKRESPONSE_OPTIONSENTRY._serialized_options = b'8\001'
  _INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY._options = None
  _INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY._serialized_options = b'8\001'
  _RETRIEVEFEATUREVIEWASSPARKRESPONSE_OPTIONSENTRY._options = None
  _RETRIEVEFEATUREVIEWASSPARKRESPONSE_OPTIONSENTRY._serialized_options = b'8\001'
  _RETRIEVEMLDATASETASSPARKRESPONSE_OPTIONSENTRY._options = None
  _RETRIEVEMLDATASETASSPARKRESPONSE_OPTIONSENTRY._serialized_options = b'8\001'
  _GENERATETRANSFORMATIONUPLOADRESPONSE_HEADERSENTRY._options = None
  _GENERATETRANSFORMATIONUPLOADRESPONSE_HEADERSENTRY._serialized_options = b'8\001'
  _BACKFILLOPTIONS_FEATUREMAPPINGENTRY._options = None
  _BACKFILLOPTIONS_FEATUREMAPPINGENTRY._serialized_options = b'8\001'
  _CORESERVICE.methods_by_name['ListJobs']._options = None
  _CORESERVICE.methods_by_name['ListJobs']._serialized_options = b'\202\323\344\223\002\016\022\014/api/v1/jobs'
  _CORESERVICE.methods_by_name['GetJob']._options = None
  _CORESERVICE.methods_by_name['GetJob']._serialized_options = b'\202\323\344\223\002\027\022\025/api/v1/jobs/{job_id}'
  _CORESERVICE.methods_by_name['GetJobProgress']._options = None
  _CORESERVICE.methods_by_name['GetJobProgress']._serialized_options = b'\202\323\344\223\002 \022\036/api/v1/jobs/{job_id}/progress'
  _CORESERVICE.methods_by_name['StartExtractSchemaJob']._options = None
  _CORESERVICE.methods_by_name['StartExtractSchemaJob']._serialized_options = b'\202\323\344\223\002 \"\033/api/v1/jobs/extract-schema:\001*'
  _CORESERVICE.methods_by_name['GetExtractSchemaJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetExtractSchemaJobOutput']._serialized_options = b'\202\323\344\223\002&\022$/api/v1/jobs/extract-schema/{job_id}'
  _CORESERVICE.methods_by_name['StartIngestJob']._options = None
  _CORESERVICE.methods_by_name['StartIngestJob']._serialized_options = b'\202\323\344\223\002\031\"\024/api/v1/ingest/start:\001*'
  _CORESERVICE.methods_by_name['GetIngestJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetIngestJobOutput']._serialized_options = b'\202\323\344\223\002\032\022\030/api/v1/ingests/{job_id}'
  _CORESERVICE.methods_by_name['StartRetrieveAsLinksJob']._options = None
  _CORESERVICE.methods_by_name['StartRetrieveAsLinksJob']._serialized_options = b'\202\323\344\223\002\034\"\027/api/v1/ingest/retrieve:\001*'
  _CORESERVICE.methods_by_name['GetRetrieveAsLinksJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetRetrieveAsLinksJobOutput']._serialized_options = b'\202\323\344\223\002\"\022 /api/v1/ingest/retrieve/{job_id}'
  _CORESERVICE.methods_by_name['RetrieveAsSpark']._options = None
  _CORESERVICE.methods_by_name['RetrieveAsSpark']._serialized_options = b'\202\323\344\223\002\"\"\035/api/v1/ingest/retrieve/spark:\001*'
  _CORESERVICE.methods_by_name['StartPreviewJob']._options = None
  _CORESERVICE.methods_by_name['StartPreviewJob']._serialized_options = b'\202\323\344\223\002\032\"\025/api/v1/preview/start:\001*'
  _CORESERVICE.methods_by_name['GetIngestWriteCredentials']._options = None
  _CORESERVICE.methods_by_name['GetIngestWriteCredentials']._serialized_options = b'\202\323\344\223\002(\022&/api/v1/ingest/credential/{session_id}'
  _CORESERVICE.methods_by_name['StartRevertIngestJob']._options = None
  _CORESERVICE.methods_by_name['StartRevertIngestJob']._serialized_options = b'\202\323\344\223\002\032\"\025/api/v1/ingest/revert:\001*'
  _CORESERVICE.methods_by_name['GetRevertIngestJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetRevertIngestJobOutput']._serialized_options = b'\202\323\344\223\002 \022\036/api/v1/ingest/revert/{job_id}'
  _CORESERVICE.methods_by_name['HasPermissionToRetrieve']._options = None
  _CORESERVICE.methods_by_name['HasPermissionToRetrieve']._serialized_options = b'\202\323\344\223\002\033\022\031/api/v1/ingest/permission'
  _CORESERVICE.methods_by_name['RegisterFeatureSet']._options = None
  _CORESERVICE.methods_by_name['RegisterFeatureSet']._serialized_options = b'\202\323\344\223\002\"\"\035/api/v1/feature-sets/register:\001*'
  _CORESERVICE.methods_by_name['CreateNewFeatureSetVersion']._options = None
  _CORESERVICE.methods_by_name['CreateNewFeatureSetVersion']._serialized_options = b'\202\323\344\223\002!\"\034/api/v1/feature-sets/version:\001*'
  _CORESERVICE.methods_by_name['GetOnlineRetrieveMeta']._options = None
  _CORESERVICE.methods_by_name['GetOnlineRetrieveMeta']._serialized_options = b'\202\323\344\223\002\031\022\027/api/v1/online-retrieve'
  _CORESERVICE.methods_by_name['GetVersion']._options = None
  _CORESERVICE.methods_by_name['GetVersion']._serialized_options = b'\202\323\344\223\002\021\022\017/api/v1/version'
  _CORESERVICE.methods_by_name['GetFeatureSet']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSet']._serialized_options = b'\202\323\344\223\002\030\"\023/api/v1/feature-set:\001*'
  _CORESERVICE.methods_by_name['GetFeatureSetById']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSetById']._serialized_options = b'\202\323\344\223\002&\022$/api/v1/feature-set/{feature_set_id}'
  _CORESERVICE.methods_by_name['GetFeatureSetsLastMinorForCurrentMajor']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSetsLastMinorForCurrentMajor']._serialized_options = b'\202\323\344\223\002\033\022\031/api/v1/feature-sets-last'
  _CORESERVICE.methods_by_name['ListFeatureSetVersions']._options = None
  _CORESERVICE.methods_by_name['ListFeatureSetVersions']._serialized_options = b'\202\323\344\223\002\036\022\034/api/v1/feature-sets/version'
  _CORESERVICE.methods_by_name['DeleteFeatureSet']._options = None
  _CORESERVICE.methods_by_name['DeleteFeatureSet']._serialized_options = b'\202\323\344\223\002\031*\024/api/v1/feature-sets:\001*'
  _CORESERVICE.methods_by_name['ListFeatureSetsPage']._options = None
  _CORESERVICE.methods_by_name['ListFeatureSetsPage']._serialized_options = b'\202\323\344\223\002\026\022\024/api/v1/feature-sets'
  _CORESERVICE.methods_by_name['FeatureSetExists']._options = None
  _CORESERVICE.methods_by_name['FeatureSetExists']._serialized_options = b'\202\323\344\223\002\035\022\033/api/v1/feature-sets/exists'
  _CORESERVICE.methods_by_name['GetIngestHistory']._options = None
  _CORESERVICE.methods_by_name['GetIngestHistory']._serialized_options = b'\202\323\344\223\002\030\022\026/api/v1/ingest/history'
  _CORESERVICE.methods_by_name['UpdateFeatureSetPrimaryKey']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetPrimaryKey']._serialized_options = b'\210\002\001\202\323\344\223\002%\032 /api/v1/feature-sets/primary-key:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetTags']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetTags']._serialized_options = b'\210\002\001\202\323\344\223\002\036\032\031/api/v1/feature-sets/tags:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetDataSourceDomains']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetDataSourceDomains']._serialized_options = b'\210\002\001\202\323\344\223\002-\032(/api/v1/feature-sets/data-source-domains:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetDescription']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetDescription']._serialized_options = b'\210\002\001\202\323\344\223\002%\032 /api/v1/feature-sets/description:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetType']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetType']._serialized_options = b'\210\002\001\202\323\344\223\002\036\032\031/api/v1/feature-sets/type:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetOwner']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetOwner']._serialized_options = b'\210\002\001\202\323\344\223\002\037\032\032/api/v1/feature-sets/owner:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetApplicationName']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetApplicationName']._serialized_options = b'\210\002\001\202\323\344\223\002*\032%/api/v1/feature-sets/application-name:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetApplicationId']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetApplicationId']._serialized_options = b'\210\002\001\202\323\344\223\002(\032#/api/v1/feature-sets/application-id:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetDeprecated']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetDeprecated']._serialized_options = b'\210\002\001\202\323\344\223\002$\032\037/api/v1/feature-sets/deprecated:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetProcessInterval']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetProcessInterval']._serialized_options = b'\210\002\001\202\323\344\223\002*\032%/api/v1/feature-sets/process-interval:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetProcessIntervalUnit']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetProcessIntervalUnit']._serialized_options = b'\210\002\001\202\323\344\223\002/\032*/api/v1/feature-sets/process-interval-unit:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetFlow']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetFlow']._serialized_options = b'\210\002\001\202\323\344\223\002\036\032\031/api/v1/feature-sets/flow:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetState']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetState']._serialized_options = b'\210\002\001\202\323\344\223\002\037\032\032/api/v1/feature-sets/state:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetSecret']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetSecret']._serialized_options = b'\210\002\001\202\323\344\223\002 \032\033/api/v1/feature-sets/secret:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetCustomData']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetCustomData']._serialized_options = b'\210\002\001\202\323\344\223\002%\032 /api/v1/feature-sets/custom-data:\001*'
  _CORESERVICE.methods_by_name['UpdateTimeToLiveOfflineInterval']._options = None
  _CORESERVICE.methods_by_name['UpdateTimeToLiveOfflineInterval']._serialized_options = b'\210\002\001\202\323\344\223\002.\032)/api/v1/feature-sets/time-to-live-offline:\001*'
  _CORESERVICE.methods_by_name['UpdateTimeToLiveOfflineIntervalUnit']._options = None
  _CORESERVICE.methods_by_name['UpdateTimeToLiveOfflineIntervalUnit']._serialized_options = b'\210\002\001\202\323\344\223\0023\032./api/v1/feature-sets/time-to-live-offline-unit:\001*'
  _CORESERVICE.methods_by_name['UpdateTimeToLiveOnlineInterval']._options = None
  _CORESERVICE.methods_by_name['UpdateTimeToLiveOnlineInterval']._serialized_options = b'\210\002\001\202\323\344\223\002-\032(/api/v1/feature-sets/time-to-live-online:\001*'
  _CORESERVICE.methods_by_name['UpdateTimeToLiveOnlineIntervalUnit']._options = None
  _CORESERVICE.methods_by_name['UpdateTimeToLiveOnlineIntervalUnit']._serialized_options = b'\210\002\001\202\323\344\223\0022\032-/api/v1/feature-sets/time-to-live-online-unit:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetOnlineNamespace']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetOnlineNamespace']._serialized_options = b'\210\002\001\202\323\344\223\002*\032%/api/v1/feature-sets/online-namespace:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetOnlineTopic']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetOnlineTopic']._serialized_options = b'\210\002\001\202\323\344\223\002&\032!/api/v1/feature-sets/online-topic:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetOnlineConnectionType']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetOnlineConnectionType']._serialized_options = b'\210\002\001\202\323\344\223\0020\032+/api/v1/feature-sets/online-connection-type:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetLegalApproved']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetLegalApproved']._serialized_options = b'\210\002\001\202\323\344\223\002(\032#/api/v1/feature-sets/legal-approved:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSetLegalApprovedNotes']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSetLegalApprovedNotes']._serialized_options = b'\210\002\001\202\323\344\223\002.\032)/api/v1/feature-sets/legal-approved-notes:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureStatus']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureStatus']._serialized_options = b'\202\323\344\223\002)\032$/api/v1/feature-sets/features/status:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureType']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureType']._serialized_options = b'\202\323\344\223\002\'\032\"/api/v1/feature-sets/features/type:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureCustomData']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureCustomData']._serialized_options = b'\202\323\344\223\002.\032)/api/v1/feature-sets/features/custom-data:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureImportance']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureImportance']._serialized_options = b'\202\323\344\223\002-\032(/api/v1/feature-sets/features/importance:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureDescription']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureDescription']._serialized_options = b'\202\323\344\223\002.\032)/api/v1/feature-sets/features/description:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureSpecial']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSpecial']._serialized_options = b'\202\323\344\223\002*\032%/api/v1/feature-sets/features/special:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureAnomalyDetection']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureAnomalyDetection']._serialized_options = b'\202\323\344\223\0024\032//api/v1/feature-sets/features/anomaly-detection:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureClassifiers']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureClassifiers']._serialized_options = b'\202\323\344\223\002.\032)/api/v1/feature-sets/features/classifiers:\001*'
  _CORESERVICE.methods_by_name['IsFeatureSetSchemaCompatible']._options = None
  _CORESERVICE.methods_by_name['IsFeatureSetSchemaCompatible']._serialized_options = b'\202\323\344\223\0024\"//api/v1/feature-sets/features/schema-compatible:\001*'
  _CORESERVICE.methods_by_name['FeatureSetSchemaPatch']._options = None
  _CORESERVICE.methods_by_name['FeatureSetSchemaPatch']._serialized_options = b'\202\323\344\223\002&\"!/api/v1/feature-sets/schema-patch:\001*'
  _CORESERVICE.methods_by_name['GetFeatureSetPreview']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSetPreview']._serialized_options = b'\202\323\344\223\002/\022-/api/v1/feature-set-previews/{feature_set_id}'
  _CORESERVICE.methods_by_name['UpdateFeatureSet']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSet']._serialized_options = b'\202\323\344\223\002*\032%/api/v1/feature-sets/{feature_set_id}:\001*'
  _CORESERVICE.methods_by_name['CreateFeatureView']._options = None
  _CORESERVICE.methods_by_name['CreateFeatureView']._serialized_options = b'\202\323\344\223\002\032\"\025/api/v1/feature-views:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureView']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureView']._serialized_options = b'\202\323\344\223\002C\032>/api/v1/feature-views/{feature_view_id}/{feature_view_version}:\001*'
  _CORESERVICE.methods_by_name['GetFeatureView']._options = None
  _CORESERVICE.methods_by_name['GetFeatureView']._serialized_options = b'\202\323\344\223\0024\0222/api/v1/projects/{project_id}/feature-views/{name}'
  _CORESERVICE.methods_by_name['ListFeatureViews']._options = None
  _CORESERVICE.methods_by_name['ListFeatureViews']._serialized_options = b'\202\323\344\223\002\027\022\025/api/v1/feature-views'
  _CORESERVICE.methods_by_name['CreateFeatureViewNewVersion']._options = None
  _CORESERVICE.methods_by_name['CreateFeatureViewNewVersion']._serialized_options = b'\202\323\344\223\002\032\"\025/api/v1/feature-views:\001*'
  _CORESERVICE.methods_by_name['StartRetrieveFeatureViewAsSparkJob']._options = None
  _CORESERVICE.methods_by_name['StartRetrieveFeatureViewAsSparkJob']._serialized_options = b'\202\323\344\223\002I\"D/api/v1/feature-views/{feature_view_id}/{feature_view_version}/spark:\001*'
  _CORESERVICE.methods_by_name['GetRetrieveFeatureViewAsSparkJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetRetrieveFeatureViewAsSparkJobOutput']._serialized_options = b'\202\323\344\223\002&\022$/api/v1/feature-views/spark/{job_id}'
  _CORESERVICE.methods_by_name['StartRetrieveFeatureViewAsLinksJob']._options = None
  _CORESERVICE.methods_by_name['StartRetrieveFeatureViewAsLinksJob']._serialized_options = b'\202\323\344\223\002I\"D/api/v1/feature-views/{feature_view_id}/{feature_view_version}/links:\001*'
  _CORESERVICE.methods_by_name['GetRetrieveFeatureViewAsLinksJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetRetrieveFeatureViewAsLinksJobOutput']._serialized_options = b'\202\323\344\223\002&\022$/api/v1/feature-views/links/{job_id}'
  _CORESERVICE.methods_by_name['DeleteFeatureView']._options = None
  _CORESERVICE.methods_by_name['DeleteFeatureView']._serialized_options = b'\202\323\344\223\002)*\'/api/v1/feature-views/{feature_view_id}'
  _CORESERVICE.methods_by_name['CreateMLDataset']._options = None
  _CORESERVICE.methods_by_name['CreateMLDataset']._serialized_options = b'\202\323\344\223\002\030\"\023/api/v1/ml-datasets:\001*'
  _CORESERVICE.methods_by_name['GetMLDatasetCreationJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetMLDatasetCreationJobOutput']._serialized_options = b'\202\323\344\223\002\036\022\034/api/v1/ml-datasets/{job_id}'
  _CORESERVICE.methods_by_name['UpdateMLDataset']._options = None
  _CORESERVICE.methods_by_name['UpdateMLDataset']._serialized_options = b'\202\323\344\223\002(\032#/api/v1/ml-datasets/{ml_dataset_id}:\001*'
  _CORESERVICE.methods_by_name['DeleteMLDataset']._options = None
  _CORESERVICE.methods_by_name['DeleteMLDataset']._serialized_options = b'\202\323\344\223\002%*#/api/v1/ml-datasets/{ml_dataset_id}'
  _CORESERVICE.methods_by_name['GetMLDataset']._options = None
  _CORESERVICE.methods_by_name['GetMLDataset']._serialized_options = b'\202\323\344\223\002%\022#/api/v1/ml-datasets/{ml_dataset_id}'
  _CORESERVICE.methods_by_name['ListMLDatasets']._options = None
  _CORESERVICE.methods_by_name['ListMLDatasets']._serialized_options = b'\202\323\344\223\002\025\022\023/api/v1/ml-datasets'
  _CORESERVICE.methods_by_name['RetrieveMLDatasetAsSpark']._options = None
  _CORESERVICE.methods_by_name['RetrieveMLDatasetAsSpark']._serialized_options = b'\202\323\344\223\002(\"#/api/v1/ml-datasets/{ml_dataset_id}:\001*'
  _CORESERVICE.methods_by_name['RetrieveMLDatasetAsLinks']._options = None
  _CORESERVICE.methods_by_name['RetrieveMLDatasetAsLinks']._serialized_options = b'\202\323\344\223\002%\022#/api/v1/ml-datasets/{ml_dataset_id}'
  _CORESERVICE.methods_by_name['RetrieveMLDatasetOnline']._options = None
  _CORESERVICE.methods_by_name['RetrieveMLDatasetOnline']._serialized_options = b'\202\323\344\223\002,\022*/api/v1/ml-datasets/{ml_dataset_id}/online'
  _CORESERVICE.methods_by_name['ListProjectsPage']._options = None
  _CORESERVICE.methods_by_name['ListProjectsPage']._serialized_options = b'\202\323\344\223\002\022\022\020/api/v1/projects'
  _CORESERVICE.methods_by_name['CreateProject']._options = None
  _CORESERVICE.methods_by_name['CreateProject']._serialized_options = b'\202\323\344\223\002\025\"\020/api/v1/projects:\001*'
  _CORESERVICE.methods_by_name['GetProject']._options = None
  _CORESERVICE.methods_by_name['GetProject']._serialized_options = b'\202\323\344\223\002!\022\037/api/v1/projects/{project_name}'
  _CORESERVICE.methods_by_name['DeleteProject']._options = None
  _CORESERVICE.methods_by_name['DeleteProject']._serialized_options = b'\202\323\344\223\002\025*\020/api/v1/projects:\001*'
  _CORESERVICE.methods_by_name['GetProjectsDefault']._options = None
  _CORESERVICE.methods_by_name['GetProjectsDefault']._serialized_options = b'\202\323\344\223\002\032\022\030/api/v1/projects/default'
  _CORESERVICE.methods_by_name['ProjectExists']._options = None
  _CORESERVICE.methods_by_name['ProjectExists']._serialized_options = b'\202\323\344\223\002&\022$/api/v1/projects/{project_id}/exists'
  _CORESERVICE.methods_by_name['UpdateProjectSecret']._options = None
  _CORESERVICE.methods_by_name['UpdateProjectSecret']._serialized_options = b'\210\002\001\202\323\344\223\002)\032$/api/v1/projects/{project_id}/secret:\001*'
  _CORESERVICE.methods_by_name['UpdateProjectLocked']._options = None
  _CORESERVICE.methods_by_name['UpdateProjectLocked']._serialized_options = b'\210\002\001\202\323\344\223\002)\032$/api/v1/projects/{project_id}/locked:\001*'
  _CORESERVICE.methods_by_name['UpdateProjectOwner']._options = None
  _CORESERVICE.methods_by_name['UpdateProjectOwner']._serialized_options = b'\210\002\001\202\323\344\223\002(\032#/api/v1/projects/{project_id}/owner:\001*'
  _CORESERVICE.methods_by_name['UpdateProjectDescription']._options = None
  _CORESERVICE.methods_by_name['UpdateProjectDescription']._serialized_options = b'\210\002\001\202\323\344\223\002.\032)/api/v1/projects/{project_id}/description:\001*'
  _CORESERVICE.methods_by_name['UpdateProjectCustomData']._options = None
  _CORESERVICE.methods_by_name['UpdateProjectCustomData']._serialized_options = b'\210\002\001\202\323\344\223\002.\032)/api/v1/projects/{project_id}/custom-data:\001*'
  _CORESERVICE.methods_by_name['UpdateProject']._options = None
  _CORESERVICE.methods_by_name['UpdateProject']._serialized_options = b'\202\323\344\223\002\"\032\035/api/v1/projects/{project_id}:\001*'
  _CORESERVICE.methods_by_name['GetAccessToken']._options = None
  _CORESERVICE.methods_by_name['GetAccessToken']._serialized_options = b'\202\323\344\223\002\027\"\022/api/v1/auth/token:\001*'
  _CORESERVICE.methods_by_name['GetUserByMail']._options = None
  _CORESERVICE.methods_by_name['GetUserByMail']._serialized_options = b'\202\323\344\223\002\034\022\032/api/v1/auth/users/{email}'
  _CORESERVICE.methods_by_name['Logout']._options = None
  _CORESERVICE.methods_by_name['Logout']._serialized_options = b'\202\323\344\223\002\030\"\023/api/v1/auth/logout:\001*'
  _CORESERVICE.methods_by_name['GetActiveUser']._options = None
  _CORESERVICE.methods_by_name['GetActiveUser']._serialized_options = b'\202\323\344\223\002\024\022\022/api/v1/auth/users'
  _CORESERVICE.methods_by_name['Login']._options = None
  _CORESERVICE.methods_by_name['Login']._serialized_options = b'\202\323\344\223\002\027\"\022/api/v1/auth/login:\001*'
  _CORESERVICE.methods_by_name['GetWebConfig']._options = None
  _CORESERVICE.methods_by_name['GetWebConfig']._serialized_options = b'\202\323\344\223\002\020\022\016/api/v1/config'
  _CORESERVICE.methods_by_name['AddFeatureSetPermission']._options = None
  _CORESERVICE.methods_by_name['AddFeatureSetPermission']._serialized_options = b'\202\323\344\223\002*\"%/api/v1/auth/feature-sets/permissions:\001*'
  _CORESERVICE.methods_by_name['AddProjectPermission']._options = None
  _CORESERVICE.methods_by_name['AddProjectPermission']._serialized_options = b'\202\323\344\223\002&\"!/api/v1/auth/projects/permissions:\001*'
  _CORESERVICE.methods_by_name['RemoveFeatureSetPermission']._options = None
  _CORESERVICE.methods_by_name['RemoveFeatureSetPermission']._serialized_options = b'\202\323\344\223\002**%/api/v1/auth/feature-sets/permissions:\001*'
  _CORESERVICE.methods_by_name['RemoveProjectPermission']._options = None
  _CORESERVICE.methods_by_name['RemoveProjectPermission']._serialized_options = b'\202\323\344\223\002&*!/api/v1/auth/projects/permissions:\001*'
  _CORESERVICE.methods_by_name['SubmitPendingProjectPermission']._options = None
  _CORESERVICE.methods_by_name['SubmitPendingProjectPermission']._serialized_options = b'\202\323\344\223\002/\"*/api/v1/permissions/projects/{resource_id}:\001*'
  _CORESERVICE.methods_by_name['SubmitPendingFeatureSetPermission']._options = None
  _CORESERVICE.methods_by_name['SubmitPendingFeatureSetPermission']._serialized_options = b'\202\323\344\223\0023\"./api/v1/permissions/feature-sets/{resource_id}:\001*'
  _CORESERVICE.methods_by_name['ListProjectPermissionsPage']._options = None
  _CORESERVICE.methods_by_name['ListProjectPermissionsPage']._serialized_options = b'\202\323\344\223\002\036\022\034/api/v1/permissions/projects'
  _CORESERVICE.methods_by_name['ListFeatureSetsPermissionsPage']._options = None
  _CORESERVICE.methods_by_name['ListFeatureSetsPermissionsPage']._serialized_options = b'\202\323\344\223\002\"\022 /api/v1/permissions/feature-sets'
  _CORESERVICE.methods_by_name['ListManageableProjectPermissionsPage']._options = None
  _CORESERVICE.methods_by_name['ListManageableProjectPermissionsPage']._serialized_options = b'\202\323\344\223\002)\022\'/api/v1/permissions/manageable-projects'
  _CORESERVICE.methods_by_name['ListManageableFeatureSetsPermissionsPage']._options = None
  _CORESERVICE.methods_by_name['ListManageableFeatureSetsPermissionsPage']._serialized_options = b'\202\323\344\223\002-\022+/api/v1/permissions/manageable-feature-sets'
  _CORESERVICE.methods_by_name['ApprovePendingPermission']._options = None
  _CORESERVICE.methods_by_name['ApprovePendingPermission']._serialized_options = b'\202\323\344\223\002!\"\034/api/v1/permissions/approval:\001*'
  _CORESERVICE.methods_by_name['RejectPendingPermission']._options = None
  _CORESERVICE.methods_by_name['RejectPendingPermission']._serialized_options = b'\202\323\344\223\002\"\"\035/api/v1/permissions/rejection:\001*'
  _CORESERVICE.methods_by_name['RevokePermission']._options = None
  _CORESERVICE.methods_by_name['RevokePermission']._serialized_options = b'\202\323\344\223\002\037\"\032/api/v1/permissions/revoke:\001*'
  _CORESERVICE.methods_by_name['GetActiveProjectPermission']._options = None
  _CORESERVICE.methods_by_name['GetActiveProjectPermission']._serialized_options = b'\202\323\344\223\0023\0221/api/v1/permissions/projects/{resource_id}/active'
  _CORESERVICE.methods_by_name['GetActiveFeatureSetPermission']._options = None
  _CORESERVICE.methods_by_name['GetActiveFeatureSetPermission']._serialized_options = b'\202\323\344\223\0027\0225/api/v1/permissions/feature-sets/{resource_id}/active'
  _CORESERVICE.methods_by_name['GetProjectOwners']._options = None
  _CORESERVICE.methods_by_name['GetProjectOwners']._serialized_options = b'\202\323\344\223\0022\0220/api/v1/permissions/project/{resource_id}/owners'
  _CORESERVICE.methods_by_name['GetFeatureSetOwners']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSetOwners']._serialized_options = b'\202\323\344\223\0027\0225/api/v1/permissions/feature-sets/{resource_id}/owners'
  _CORESERVICE.methods_by_name['RevokeToken']._options = None
  _CORESERVICE.methods_by_name['RevokeToken']._serialized_options = b'\202\323\344\223\002\036\"\031/api/v1/auth/token/revoke:\001*'
  _CORESERVICE.methods_by_name['GenerateToken']._options = None
  _CORESERVICE.methods_by_name['GenerateToken']._serialized_options = b'\202\323\344\223\002\027\"\022/api/v1/auth/token:\001*'
  _CORESERVICE.methods_by_name['ListTokens']._options = None
  _CORESERVICE.methods_by_name['ListTokens']._serialized_options = b'\202\323\344\223\002\025\022\023/api/v1/auth/tokens'
  _CORESERVICE.methods_by_name['GetToken']._options = None
  _CORESERVICE.methods_by_name['GetToken']._serialized_options = b'\202\323\344\223\002 \022\036/api/v1/auth/tokens/{token_id}'
  _CORESERVICE.methods_by_name['OnlineRetrieve']._options = None
  _CORESERVICE.methods_by_name['OnlineRetrieve']._serialized_options = b'\202\323\344\223\002\031\022\027/api/v1/online-retrieve'
  _CORESERVICE.methods_by_name['OnlineIngest']._options = None
  _CORESERVICE.methods_by_name['OnlineIngest']._serialized_options = b'\202\323\344\223\002\027\022\025/api/v1/online-ingest'
  _CORESERVICE.methods_by_name['StartMaterializationOnlineJob']._options = None
  _CORESERVICE.methods_by_name['StartMaterializationOnlineJob']._serialized_options = b'\202\323\344\223\002\023\"\016/api/v1/online:\001*'
  _CORESERVICE.methods_by_name['GetMaterializationOnlineJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetMaterializationOnlineJobOutput']._serialized_options = b'\202\323\344\223\002\031\022\027/api/v1/online/{job_id}'
  _CORESERVICE.methods_by_name['GetComputeStatisticsJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetComputeStatisticsJobOutput']._serialized_options = b'\202\323\344\223\002%\022#/api/v1/compute-statistics/{job_id}'
  _CORESERVICE.methods_by_name['GetComputeRecommendationClassifiersJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetComputeRecommendationClassifiersJobOutput']._serialized_options = b'\202\323\344\223\002*\022(/api/v1/compute-recommendations/{job_id}'
  _CORESERVICE.methods_by_name['GenerateTransformationUpload']._options = None
  _CORESERVICE.methods_by_name['GenerateTransformationUpload']._serialized_options = b'\202\323\344\223\002\034\"\027/api/v1/transformations:\001*'
  _CORESERVICE.methods_by_name['ListRecommendationClassifiers']._options = None
  _CORESERVICE.methods_by_name['ListRecommendationClassifiers']._serialized_options = b'\202\323\344\223\0022\0220/api/v1/feature-sets/recommendations-classifiers'
  _CORESERVICE.methods_by_name['CreateRecommendationClassifier']._options = None
  _CORESERVICE.methods_by_name['CreateRecommendationClassifier']._serialized_options = b'\202\323\344\223\0025\"0/api/v1/feature-sets/recommendations-classifiers:\001*'
  _CORESERVICE.methods_by_name['UpdateRecommendationClassifier']._options = None
  _CORESERVICE.methods_by_name['UpdateRecommendationClassifier']._serialized_options = b'\202\323\344\223\002<\0327/api/v1/feature-sets/recommendations-classifiers/{name}:\001*'
  _CORESERVICE.methods_by_name['DeleteRecommendationClassifier']._options = None
  _CORESERVICE.methods_by_name['DeleteRecommendationClassifier']._serialized_options = b'\202\323\344\223\002D*B/api/v1/feature-sets/recommendations-classifiers/{classifier_name}'
  _CORESERVICE.methods_by_name['GetRecommendations']._options = None
  _CORESERVICE.methods_by_name['GetRecommendations']._serialized_options = b'\202\323\344\223\002&\022$/api/v1/feature-sets/recommendations'
  _CORESERVICE.methods_by_name['GetDashboard']._options = None
  _CORESERVICE.methods_by_name['GetDashboard']._serialized_options = b'\202\323\344\223\002\023\022\021/api/v1/dashboard'
  _CORESERVICE.methods_by_name['SearchProjects']._options = None
  _CORESERVICE.methods_by_name['SearchProjects']._serialized_options = b'\202\323\344\223\002\031\022\027/api/v1/search/projects'
  _CORESERVICE.methods_by_name['SearchFeatureSets']._options = None
  _CORESERVICE.methods_by_name['SearchFeatureSets']._serialized_options = b'\202\323\344\223\002\035\022\033/api/v1/search/feature-sets'
  _CORESERVICE.methods_by_name['SearchFeatures']._options = None
  _CORESERVICE.methods_by_name['SearchFeatures']._serialized_options = b'\202\323\344\223\002\030\022\026/api/v1/search/feature'
  _CORESERVICE.methods_by_name['GetFeature']._options = None
  _CORESERVICE.methods_by_name['GetFeature']._serialized_options = b'\202\323\344\223\002=\022;/api/v1/feature-sets/{feature_set_id}/features/{feature_id}'
  _CORESERVICE.methods_by_name['ListFeature']._options = None
  _CORESERVICE.methods_by_name['ListFeature']._serialized_options = b'\202\323\344\223\0020\022./api/v1/feature-sets/{feature_set_id}/features'
  _CORESERVICE.methods_by_name['UpdateFeature']._options = None
  _CORESERVICE.methods_by_name['UpdateFeature']._serialized_options = b'\202\323\344\223\002@\032;/api/v1/feature-sets/{feature_set_id}/features/{feature_id}:\001*'
  _CORESERVICE.methods_by_name['GetListableFeatureSet']._options = None
  _CORESERVICE.methods_by_name['GetListableFeatureSet']._serialized_options = b'\202\323\344\223\0020\022./api/v1/listable-feature-sets/{feature_set_id}'
  _CORESERVICE.methods_by_name['ScheduleIngestJob']._options = None
  _CORESERVICE.methods_by_name['ScheduleIngestJob']._serialized_options = b'\202\323\344\223\002 \"\033/api/v1/schedules/ingestion:\001*'
  _CORESERVICE.methods_by_name['ListScheduledTasks']._options = None
  _CORESERVICE.methods_by_name['ListScheduledTasks']._serialized_options = b'\202\323\344\223\002\023\022\021/api/v1/schedules'
  _CORESERVICE.methods_by_name['GetScheduledTask']._options = None
  _CORESERVICE.methods_by_name['GetScheduledTask']._serialized_options = b'\202\323\344\223\002\'\022%/api/v1/schedules/{scheduled_task_id}'
  _CORESERVICE.methods_by_name['DeleteScheduledTask']._options = None
  _CORESERVICE.methods_by_name['DeleteScheduledTask']._serialized_options = b'\202\323\344\223\002\'*%/api/v1/schedules/{scheduled_task_id}'
  _CORESERVICE.methods_by_name['UpdateScheduledTask']._options = None
  _CORESERVICE.methods_by_name['UpdateScheduledTask']._serialized_options = b'\202\323\344\223\002*\032%/api/v1/schedules/{scheduled_task_id}:\001*'
  _CORESERVICE.methods_by_name['ScheduleLazyIngestTask']._options = None
  _CORESERVICE.methods_by_name['ScheduleLazyIngestTask']._serialized_options = b'\202\323\344\223\002%\" /api/v1/schedules/lazy/ingestion:\001*'
  _CORESERVICE.methods_by_name['StartLazyIngestTask']._options = None
  _CORESERVICE.methods_by_name['StartLazyIngestTask']._serialized_options = b'\202\323\344\223\002(\022&/api/v1/schedules/lazy/ingestion/start'
  _CORESERVICE.methods_by_name['GetLazyIngestTask']._options = None
  _CORESERVICE.methods_by_name['GetLazyIngestTask']._serialized_options = b'\202\323\344\223\0023\0221/api/v1/schedules/lazy/ingestion/{feature_set_id}'
  _CORESERVICE.methods_by_name['ListTransformationFunctions']._options = None
  _CORESERVICE.methods_by_name['ListTransformationFunctions']._serialized_options = b'\202\323\344\223\002\"\022 /api/v1/transformation_functions'
  _CORESERVICE.methods_by_name['GetTransformationFunction']._options = None
  _CORESERVICE.methods_by_name['GetTransformationFunction']._serialized_options = b'\202\323\344\223\002A\022?/api/v1/transformation_functions/{transformation_function_name}'
  _CORESERVICE.methods_by_name['GetBackfillJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetBackfillJobOutput']._serialized_options = b'\202\323\344\223\002\033\022\031/api/v1/backfill/{job_id}'
  _globals['_JOBTYPE']._serialized_start=35528
  _globals['_JOBTYPE']._serialized_end=35807
  _globals['_PERMISSIONTYPE']._serialized_start=35809
  _globals['_PERMISSIONTYPE']._serialized_end=35897
  _globals['_ACTIVEPERMISSION']._serialized_start=35900
  _globals['_ACTIVEPERMISSION']._serialized_end=36109
  _globals['_FEATUREFILTEROPERATOR']._serialized_start=36112
  _globals['_FEATUREFILTEROPERATOR']._serialized_end=36364
  _globals['_FEATUREFILTERLOGICOPERATOR']._serialized_start=36367
  _globals['_FEATUREFILTERLOGICOPERATOR']._serialized_end=36515
  _globals['_FEATUREDATATYPE']._serialized_start=36518
  _globals['_FEATUREDATATYPE']._serialized_end=36668
  _globals['_PROCESSINTERVALUNIT']._serialized_start=36670
  _globals['_PROCESSINTERVALUNIT']._serialized_end=36783
  _globals['_TRANSFORMATIONTYPE']._serialized_start=36785
  _globals['_TRANSFORMATIONTYPE']._serialized_end=36889
  _globals['_RESOURCETYPE']._serialized_start=36891
  _globals['_RESOURCETYPE']._serialized_end=36935
  _globals['_PERMISSIONSTATE']._serialized_start=36937
  _globals['_PERMISSIONSTATE']._serialized_end=37021
  _globals['_TASKTYPE']._serialized_start=37023
  _globals['_TASKTYPE']._serialized_end=37062
  _globals['_UPDATABLEPROJECTFIELD']._serialized_start=37065
  _globals['_UPDATABLEPROJECTFIELD']._serialized_end=37203
  _globals['_UPDATABLEFEATURESETFIELD']._serialized_start=37206
  _globals['_UPDATABLEFEATURESETFIELD']._serialized_end=37959
  _globals['_UPDATABLEFEATUREFIELD']._serialized_start=37962
  _globals['_UPDATABLEFEATUREFIELD']._serialized_end=38199
  _globals['_FEATURECUSTOMDATAUPDATEREQUEST']._serialized_start=499
  _globals['_FEATURECUSTOMDATAUPDATEREQUEST']._serialized_end=668
  _globals['_IDENTITYPROVIDERDETAILS']._serialized_start=670
  _globals['_IDENTITYPROVIDERDETAILS']._serialized_end=752
  _globals['_GETWEBCONFIGRESPONSE']._serialized_start=754
  _globals['_GETWEBCONFIGRESPONSE']._serialized_end=873
  _globals['_FEATURESETCUSTOMDATAUPDATEREQUEST']._serialized_start=876
  _globals['_FEATURESETCUSTOMDATAUPDATEREQUEST']._serialized_end=1017
  _globals['_PROJECTCUSTOMDATAUPDATEREQUEST']._serialized_start=1019
  _globals['_PROJECTCUSTOMDATAUPDATEREQUEST']._serialized_end=1115
  _globals['_FEATURESETTYPEUPDATEREQUEST']._serialized_start=1118
  _globals['_FEATURESETTYPEUPDATEREQUEST']._serialized_end=1272
  _globals['_GETFEATURESETSLASTMINORFORCURRENTMAJORREQUEST']._serialized_start=1274
  _globals['_GETFEATURESETSLASTMINORFORCURRENTMAJORREQUEST']._serialized_end=1383
  _globals['_FEATURETYPEUPDATEREQUEST']._serialized_start=1386
  _globals['_FEATURETYPEUPDATEREQUEST']._serialized_end=1565
  _globals['_FEATUREDOUBLEFIELDUPDATEREQUEST']._serialized_start=1568
  _globals['_FEATUREDOUBLEFIELDUPDATEREQUEST']._serialized_end=1713
  _globals['_FEATURESTRINGFIELDUPDATEREQUEST']._serialized_start=1716
  _globals['_FEATURESTRINGFIELDUPDATEREQUEST']._serialized_end=1861
  _globals['_FEATURESTRINGARRAYFIELDUPDATEREQUEST']._serialized_start=1864
  _globals['_FEATURESTRINGARRAYFIELDUPDATEREQUEST']._serialized_end=2014
  _globals['_FEATUREBOOLEANFIELDUPDATEREQUEST']._serialized_start=2017
  _globals['_FEATUREBOOLEANFIELDUPDATEREQUEST']._serialized_end=2163
  _globals['_FEATURESETTIMETOLIVEONLINEINTERVALUNITUPDATEREQUEST']._serialized_start=2166
  _globals['_FEATURESETTIMETOLIVEONLINEINTERVALUNITUPDATEREQUEST']._serialized_end=2355
  _globals['_FEATURESETTIMETOLIVEOFFLINEINTERVALUNITUPDATEREQUEST']._serialized_start=2358
  _globals['_FEATURESETTIMETOLIVEOFFLINEINTERVALUNITUPDATEREQUEST']._serialized_end=2549
  _globals['_FEATURESETINTFIELDUPDATEREQUEST']._serialized_start=2551
  _globals['_FEATURESETINTFIELDUPDATEREQUEST']._serialized_end=2665
  _globals['_FEATURESETPROCESSINTERVALUNITUPDATEREQUEST']._serialized_start=2668
  _globals['_FEATURESETPROCESSINTERVALUNITUPDATEREQUEST']._serialized_end=2842
  _globals['_FEATURESETSTRINGARRAYFIELDUPDATEREQUEST']._serialized_start=2844
  _globals['_FEATURESETSTRINGARRAYFIELDUPDATEREQUEST']._serialized_end=2966
  _globals['_FEATURESETBOOLEANFIELDUPDATEREQUEST']._serialized_start=2968
  _globals['_FEATURESETBOOLEANFIELDUPDATEREQUEST']._serialized_end=3086
  _globals['_FEATURESETSTRINGFIELDUPDATEREQUEST']._serialized_start=3088
  _globals['_FEATURESETSTRINGFIELDUPDATEREQUEST']._serialized_end=3205
  _globals['_FEATURESETUSERFIELDUPDATEREQUEST']._serialized_start=3208
  _globals['_FEATURESETUSERFIELDUPDATEREQUEST']._serialized_end=3366
  _globals['_PROJECTBOOLEANFIELDUPDATEREQUEST']._serialized_start=3368
  _globals['_PROJECTBOOLEANFIELDUPDATEREQUEST']._serialized_end=3441
  _globals['_PROJECTSTRINGFIELDUPDATEREQUEST']._serialized_start=3443
  _globals['_PROJECTSTRINGFIELDUPDATEREQUEST']._serialized_end=3515
  _globals['_PROJECTUSERFIELDUPDATEREQUEST']._serialized_start=3517
  _globals['_PROJECTUSERFIELDUPDATEREQUEST']._serialized_end=3630
  _globals['_FEATURESETEXISTSREQUEST']._serialized_start=3632
  _globals['_FEATURESETEXISTSREQUEST']._serialized_end=3701
  _globals['_GETINGESTHISTORYREQUEST']._serialized_start=3703
  _globals['_GETINGESTHISTORYREQUEST']._serialized_end=3789
  _globals['_PROJECTEXISTSREQUEST']._serialized_start=3791
  _globals['_PROJECTEXISTSREQUEST']._serialized_end=3833
  _globals['_EXISTSRESPONSE']._serialized_start=3835
  _globals['_EXISTSRESPONSE']._serialized_end=3867
  _globals['_PROJECTSDEFAULTRESPONSE']._serialized_start=3869
  _globals['_PROJECTSDEFAULTRESPONSE']._serialized_end=3910
  _globals['_HASPERMISSIONTORETRIEVEREQUEST']._serialized_start=3912
  _globals['_HASPERMISSIONTORETRIEVEREQUEST']._serialized_end=3992
  _globals['_HASPERMISSIONTORETRIEVERESPONSE']._serialized_start=3994
  _globals['_HASPERMISSIONTORETRIEVERESPONSE']._serialized_end=4060
  _globals['_STARTREVERTINGESTJOBREQUEST']._serialized_start=4062
  _globals['_STARTREVERTINGESTJOBREQUEST']._serialized_end=4171
  _globals['_ONLINERETRIEVEMETA']._serialized_start=4173
  _globals['_ONLINERETRIEVEMETA']._serialized_end=4274
  _globals['_REFRESHTOKENREQUEST']._serialized_start=4276
  _globals['_REFRESHTOKENREQUEST']._serialized_end=4320
  _globals['_GETUSERBYMAILREQUEST']._serialized_start=4322
  _globals['_GETUSERBYMAILREQUEST']._serialized_end=4359
  _globals['_GETUSERBYMAILRESPONSE']._serialized_start=4361
  _globals['_GETUSERBYMAILRESPONSE']._serialized_end=4441
  _globals['_TOKENREQUEST']._serialized_start=4443
  _globals['_TOKENREQUEST']._serialized_end=4475
  _globals['_GENERATETOKENREQUEST']._serialized_start=4477
  _globals['_GENERATETOKENREQUEST']._serialized_end=4583
  _globals['_TOKENRESPONSE']._serialized_start=4585
  _globals['_TOKENRESPONSE']._serialized_end=4664
  _globals['_LISTTOKENSRESPONSE']._serialized_start=4666
  _globals['_LISTTOKENSRESPONSE']._serialized_end=4751
  _globals['_RAWTOKENRESPONSE']._serialized_start=4753
  _globals['_RAWTOKENRESPONSE']._serialized_end=4786
  _globals['_LISTJOBSREQUEST']._serialized_start=4789
  _globals['_LISTJOBSREQUEST']._serialized_end=4938
  _globals['_LISTJOBSRESPONSE']._serialized_start=4940
  _globals['_LISTJOBSRESPONSE']._serialized_end=5005
  _globals['_FEATURESETSCHEMACOMPATIBILITYREQUEST']._serialized_start=5008
  _globals['_FEATURESETSCHEMACOMPATIBILITYREQUEST']._serialized_end=5205
  _globals['_FEATURESETSCHEMACOMPATIBILITYRESPONSE']._serialized_start=5207
  _globals['_FEATURESETSCHEMACOMPATIBILITYRESPONSE']._serialized_end=5269
  _globals['_FEATURESETSCHEMAPATCHREQUEST']._serialized_start=5272
  _globals['_FEATURESETSCHEMAPATCHREQUEST']._serialized_end=5461
  _globals['_FEATURESETSCHEMAPATCHRESPONSE']._serialized_start=5463
  _globals['_FEATURESETSCHEMAPATCHRESPONSE']._serialized_end=5553
  _globals['_JOBID']._serialized_start=5555
  _globals['_JOBID']._serialized_end=5578
  _globals['_GETRECOMMENDATIONREQUEST']._serialized_start=5580
  _globals['_GETRECOMMENDATIONREQUEST']._serialized_end=5667
  _globals['_GETRECOMMENDATIONRESPONSE']._serialized_start=5670
  _globals['_GETRECOMMENDATIONRESPONSE']._serialized_end=5973
  _globals['_GETRECOMMENDATIONRESPONSE_JOIN']._serialized_start=5777
  _globals['_GETRECOMMENDATIONRESPONSE_JOIN']._serialized_end=5820
  _globals['_GETRECOMMENDATIONRESPONSE_MATCH']._serialized_start=5823
  _globals['_GETRECOMMENDATIONRESPONSE_MATCH']._serialized_end=5973
  _globals['_JOB']._serialized_start=5975
  _globals['_JOB']._serialized_end=6086
  _globals['_JOBPROGRESSINPUT']._serialized_start=6088
  _globals['_JOBPROGRESSINPUT']._serialized_end=6142
  _globals['_JOBPROGRESSOUTPUT']._serialized_start=6145
  _globals['_JOBPROGRESSOUTPUT']._serialized_end=6343
  _globals['_JOBPROGRESSOUTPUT_PROGRESS']._serialized_start=6240
  _globals['_JOBPROGRESSOUTPUT_PROGRESS']._serialized_end=6343
  _globals['_FEATURESETPERMISSIONREQUEST']._serialized_start=6346
  _globals['_FEATURESETPERMISSIONREQUEST']._serialized_end=6521
  _globals['_PROJECTPERMISSIONREQUEST']._serialized_start=6524
  _globals['_PROJECTPERMISSIONREQUEST']._serialized_end=6689
  _globals['_STARTEXTRACTSCHEMAJOBREQUEST']._serialized_start=6692
  _globals['_STARTEXTRACTSCHEMAJOBREQUEST']._serialized_end=6924
  _globals['_EXTRACTSCHEMARESPONSE']._serialized_start=6927
  _globals['_EXTRACTSCHEMARESPONSE']._serialized_end=7079
  _globals['_LISTFEATURESETSVERSIONREQUEST']._serialized_start=7081
  _globals['_LISTFEATURESETSVERSIONREQUEST']._serialized_end=7173
  _globals['_FEATURESETRESPONSE']._serialized_start=7176
  _globals['_FEATURESETRESPONSE']._serialized_end=7305
  _globals['_UPDATEFEATURESETRESPONSE']._serialized_start=7307
  _globals['_UPDATEFEATURESETRESPONSE']._serialized_end=7402
  _globals['_UPDATEPROJECTRESPONSE']._serialized_start=7404
  _globals['_UPDATEPROJECTRESPONSE']._serialized_end=7489
  _globals['_UPDATEFEATURERESPONSE']._serialized_start=7492
  _globals['_UPDATEFEATURERESPONSE']._serialized_end=7646
  _globals['_PROJECTRESPONSE']._serialized_start=7648
  _globals['_PROJECTRESPONSE']._serialized_end=7719
  _globals['_LOGINRESPONSE']._serialized_start=7721
  _globals['_LOGINRESPONSE']._serialized_end=7794
  _globals['_GETACTIVEUSERRESPONSE']._serialized_start=7796
  _globals['_GETACTIVEUSERRESPONSE']._serialized_end=7876
  _globals['_GETPROJECTREQUEST']._serialized_start=7878
  _globals['_GETPROJECTREQUEST']._serialized_end=7919
  _globals['_DELETEFEATURESETREQUEST']._serialized_start=7921
  _globals['_DELETEFEATURESETREQUEST']._serialized_end=8007
  _globals['_LOGOUTREQUEST']._serialized_start=8009
  _globals['_LOGOUTREQUEST']._serialized_end=8047
  _globals['_USERBASICINFO']._serialized_start=8049
  _globals['_USERBASICINFO']._serialized_end=8105
  _globals['_USER']._serialized_start=8107
  _globals['_USER']._serialized_end=8196
  _globals['_ACCESSTOKENRESPONSE']._serialized_start=8198
  _globals['_ACCESSTOKENRESPONSE']._serialized_end=8319
  _globals['_DELETEPROJECTREQUEST']._serialized_start=8321
  _globals['_DELETEPROJECTREQUEST']._serialized_end=8397
  _globals['_UPDATEPROJECTMETADATAREQUEST']._serialized_start=8399
  _globals['_UPDATEPROJECTMETADATAREQUEST']._serialized_end=8483
  _globals['_CREATEPROJECTREQUEST']._serialized_start=8486
  _globals['_CREATEPROJECTREQUEST']._serialized_end=8629
  _globals['_CREATEPROJECTRESPONSE']._serialized_start=8631
  _globals['_CREATEPROJECTRESPONSE']._serialized_end=8732
  _globals['_LISTPROJECTSRESPONSE']._serialized_start=8734
  _globals['_LISTPROJECTSRESPONSE']._serialized_end=8811
  _globals['_GETINGESTHISTORYRESPONSE']._serialized_start=8813
  _globals['_GETINGESTHISTORYRESPONSE']._serialized_end=8909
  _globals['_LISTFEATURESETSACROSSPROJECTSREQUEST']._serialized_start=8911
  _globals['_LISTFEATURESETSACROSSPROJECTSREQUEST']._serialized_end=9022
  _globals['_LISTFEATURESETSPAGEREQUEST']._serialized_start=9025
  _globals['_LISTFEATURESETSPAGEREQUEST']._serialized_end=9165
  _globals['_LISTFEATURESETSPAGERESPONSE']._serialized_start=9167
  _globals['_LISTFEATURESETSPAGERESPONSE']._serialized_end=9283
  _globals['_AWSCREDENTIALS']._serialized_start=9286
  _globals['_AWSCREDENTIALS']._serialized_end=9419
  _globals['_AZURECREDENTIALS']._serialized_start=9422
  _globals['_AZURECREDENTIALS']._serialized_end=9588
  _globals['_SNOWFLAKECREDENTIALS']._serialized_start=9590
  _globals['_SNOWFLAKECREDENTIALS']._serialized_end=9644
  _globals['_JDBCCREDENTIALS']._serialized_start=9646
  _globals['_JDBCCREDENTIALS']._serialized_end=9695
  _globals['_CREDENTIALS']._serialized_start=9698
  _globals['_CREDENTIALS']._serialized_end=9972
  _globals['_LISTFEATURESETSRESPONSE']._serialized_start=9974
  _globals['_LISTFEATURESETSRESPONSE']._serialized_end=10061
  _globals['_LISTFEATURESETVERSIONSRESPONSE']._serialized_start=10063
  _globals['_LISTFEATURESETVERSIONSRESPONSE']._serialized_end=10171
  _globals['_FEATURESETVERSIONDESCRIPTION']._serialized_start=10173
  _globals['_FEATURESETVERSIONDESCRIPTION']._serialized_end=10299
  _globals['_GETFEATURESETREQUEST']._serialized_start=10301
  _globals['_GETFEATURESETREQUEST']._serialized_end=10420
  _globals['_STARTINGESTJOBREQUEST']._serialized_start=10423
  _globals['_STARTINGESTJOBREQUEST']._serialized_end=10640
  _globals['_INGESTRESPONSE']._serialized_start=10643
  _globals['_INGESTRESPONSE']._serialized_end=10987
  _globals['_INGESTRESPONSE_INGESTMETA']._serialized_start=10792
  _globals['_INGESTRESPONSE_INGESTMETA']._serialized_end=10987
  _globals['_RETRIEVEREQUEST']._serialized_start=10990
  _globals['_RETRIEVEREQUEST']._serialized_end=11155
  _globals['_RETRIEVEASLINKSRESPONSE']._serialized_start=11158
  _globals['_RETRIEVEASLINKSRESPONSE']._serialized_end=11297
  _globals['_RETRIEVEASSPARKRESPONSE']._serialized_start=11300
  _globals['_RETRIEVEASSPARKRESPONSE']._serialized_end=11578
  _globals['_RETRIEVEASSPARKRESPONSE_OPTIONSENTRY']._serialized_start=11532
  _globals['_RETRIEVEASSPARKRESPONSE_OPTIONSENTRY']._serialized_end=11578
  _globals['_PREVIEWREQUEST']._serialized_start=11580
  _globals['_PREVIEWREQUEST']._serialized_end=11657
  _globals['_STARTMATERIALIZATIONONLINEREQUEST']._serialized_start=11659
  _globals['_STARTMATERIALIZATIONONLINEREQUEST']._serialized_end=11755
  _globals['_MATERIALIZATIONONLINERESPONSE']._serialized_start=11757
  _globals['_MATERIALIZATIONONLINERESPONSE']._serialized_end=11875
  _globals['_INGESTWRITECREDENTIALREQUEST']._serialized_start=11877
  _globals['_INGESTWRITECREDENTIALREQUEST']._serialized_end=11927
  _globals['_INGESTWRITECREDENTIALRESPONSE']._serialized_start=11930
  _globals['_INGESTWRITECREDENTIALRESPONSE']._serialized_end=12132
  _globals['_INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY']._serialized_start=11532
  _globals['_INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY']._serialized_end=11578
  _globals['_RAWDATALOCATION']._serialized_start=12135
  _globals['_RAWDATALOCATION']._serialized_end=12884
  _globals['_ONLINESOURCESPEC']._serialized_start=12886
  _globals['_ONLINESOURCESPEC']._serialized_end=12939
  _globals['_CSVFILESPEC']._serialized_start=12941
  _globals['_CSVFILESPEC']._serialized_end=12987
  _globals['_JSONFILESPEC']._serialized_start=12989
  _globals['_JSONFILESPEC']._serialized_end=13036
  _globals['_PARQUETFILESPEC']._serialized_start=13038
  _globals['_PARQUETFILESPEC']._serialized_end=13069
  _globals['_TEMPPARQUETFILESPEC']._serialized_start=13071
  _globals['_TEMPPARQUETFILESPEC']._serialized_end=13106
  _globals['_PROXY']._serialized_start=13108
  _globals['_PROXY']._serialized_end=13175
  _globals['_SNOWFLAKETABLESPEC']._serialized_start=13178
  _globals['_SNOWFLAKETABLESPEC']._serialized_end=13393
  _globals['_JDBCTABLESPEC']._serialized_start=13396
  _globals['_JDBCTABLESPEC']._serialized_end=13577
  _globals['_DELTATABLESPEC']._serialized_start=13579
  _globals['_DELTATABLESPEC']._serialized_end=13697
  _globals['_CSVFOLDERSPEC']._serialized_start=13699
  _globals['_CSVFOLDERSPEC']._serialized_end=13778
  _globals['_PARQUETFOLDERSPEC']._serialized_start=13780
  _globals['_PARQUETFOLDERSPEC']._serialized_end=13844
  _globals['_JSONFOLDERSPEC']._serialized_start=13846
  _globals['_JSONFOLDERSPEC']._serialized_end=13926
  _globals['_MOJOTRANSFORMATION']._serialized_start=13928
  _globals['_MOJOTRANSFORMATION']._serialized_end=13966
  _globals['_SPARKPIPELINETRANSFORMATION']._serialized_start=13968
  _globals['_SPARKPIPELINETRANSFORMATION']._serialized_end=14015
  _globals['_JOINTRANSFORMATION']._serialized_start=14017
  _globals['_JOINTRANSFORMATION']._serialized_end=14074
  _globals['_VERSIONEDID']._serialized_start=14076
  _globals['_VERSIONEDID']._serialized_end=14124
  _globals['_TRANSFORMATION']._serialized_start=14127
  _globals['_TRANSFORMATION']._serialized_end=14363
  _globals['_DERIVEDINFORMATION']._serialized_start=14366
  _globals['_DERIVEDINFORMATION']._serialized_end=14520
  _globals['_SELECTEDFEATURE']._serialized_start=14522
  _globals['_SELECTEDFEATURE']._serialized_end=14596
  _globals['_FILTERCONDITIONUNION']._serialized_start=14599
  _globals['_FILTERCONDITIONUNION']._serialized_end=14760
  _globals['_FEATUREFILTER']._serialized_start=14763
  _globals['_FEATUREFILTER']._serialized_end=14924
  _globals['_FEATUREFILTERLOGIC']._serialized_start=14927
  _globals['_FEATUREFILTERLOGIC']._serialized_end=15156
  _globals['_FEATUREQUERY']._serialized_start=15159
  _globals['_FEATUREQUERY']._serialized_end=15802
  _globals['_FEATUREQUERY_FROM']._serialized_start=15446
  _globals['_FEATUREQUERY_FROM']._serialized_end=15529
  _globals['_FEATUREQUERY_JOIN']._serialized_start=15532
  _globals['_FEATUREQUERY_JOIN']._serialized_end=15802
  _globals['_FEATUREQUERY_JOIN_ON']._serialized_start=15679
  _globals['_FEATUREQUERY_JOIN_ON']._serialized_end=15802
  _globals['_FEATUREVIEW']._serialized_start=15805
  _globals['_FEATUREVIEW']._serialized_end=15959
  _globals['_CREATEFEATUREVIEWREQUEST']._serialized_start=15962
  _globals['_CREATEFEATUREVIEWREQUEST']._serialized_end=16100
  _globals['_UPDATEFEATUREVIEWREQUEST']._serialized_start=16102
  _globals['_UPDATEFEATUREVIEWREQUEST']._serialized_end=16204
  _globals['_CREATEFEATUREVIEWNEWVERSIONREQUEST']._serialized_start=16207
  _globals['_CREATEFEATUREVIEWNEWVERSIONREQUEST']._serialized_end=16355
  _globals['_GETFEATUREVIEWREQUEST']._serialized_start=16357
  _globals['_GETFEATUREVIEWREQUEST']._serialized_end=16431
  _globals['_FEATUREVIEWRESPONSE']._serialized_start=16433
  _globals['_FEATUREVIEWRESPONSE']._serialized_end=16517
  _globals['_LISTFEATUREVIEWSREQUEST']._serialized_start=16519
  _globals['_LISTFEATUREVIEWSREQUEST']._serialized_end=16564
  _globals['_LISTFEATUREVIEWSRESPONSE']._serialized_start=16566
  _globals['_LISTFEATUREVIEWSRESPONSE']._serialized_end=16656
  _globals['_RETRIEVEFEATUREVIEWASSPARKREQUEST']._serialized_start=16659
  _globals['_RETRIEVEFEATUREVIEWASSPARKREQUEST']._serialized_end=16859
  _globals['_RETRIEVEFEATUREVIEWASSPARKRESPONSE']._serialized_start=16862
  _globals['_RETRIEVEFEATUREVIEWASSPARKRESPONSE']._serialized_end=17074
  _globals['_RETRIEVEFEATUREVIEWASSPARKRESPONSE_OPTIONSENTRY']._serialized_start=11532
  _globals['_RETRIEVEFEATUREVIEWASSPARKRESPONSE_OPTIONSENTRY']._serialized_end=11578
  _globals['_RETRIEVEFEATUREVIEWASASLINKSREQUEST']._serialized_start=17077
  _globals['_RETRIEVEFEATUREVIEWASASLINKSREQUEST']._serialized_end=17259
  _globals['_RETRIEVEFEATUREVIEWASASLINKSRESPONSE']._serialized_start=17261
  _globals['_RETRIEVEFEATUREVIEWASASLINKSRESPONSE']._serialized_end=17323
  _globals['_DELETEFEATUREVIEWREQUEST']._serialized_start=17325
  _globals['_DELETEFEATUREVIEWREQUEST']._serialized_end=17376
  _globals['_MLDATASETFEATURE']._serialized_start=17379
  _globals['_MLDATASETFEATURE']._serialized_end=17778
  _globals['_MLDATASET']._serialized_start=17781
  _globals['_MLDATASET']._serialized_end=18283
  _globals['_MLDATASET_MLDATASETSTATE']._serialized_start=18175
  _globals['_MLDATASET_MLDATASETSTATE']._serialized_end=18283
  _globals['_CREATEMLDATASETREQUEST']._serialized_start=18286
  _globals['_CREATEMLDATASETREQUEST']._serialized_end=18504
  _globals['_UPDATEMLDATASETREQUEST']._serialized_start=18506
  _globals['_UPDATEMLDATASETREQUEST']._serialized_end=18574
  _globals['_DELETEMLDATASETREQUEST']._serialized_start=18576
  _globals['_DELETEMLDATASETREQUEST']._serialized_end=18623
  _globals['_CREATEMLDATASETRESPONSE']._serialized_start=18626
  _globals['_CREATEMLDATASETRESPONSE']._serialized_end=18758
  _globals['_GETMLDATASETREQUEST']._serialized_start=18760
  _globals['_GETMLDATASETREQUEST']._serialized_end=18861
  _globals['_LISTMLDATASETSREQUEST']._serialized_start=18863
  _globals['_LISTMLDATASETSREQUEST']._serialized_end=18941
  _globals['_LISTMLDATASETSRESPONSE']._serialized_start=18943
  _globals['_LISTMLDATASETSRESPONSE']._serialized_end=19027
  _globals['_RETRIEVEMLDATASETASSPARKREQUEST']._serialized_start=19029
  _globals['_RETRIEVEMLDATASETASSPARKREQUEST']._serialized_end=19105
  _globals['_RETRIEVEMLDATASETASSPARKRESPONSE']._serialized_start=19108
  _globals['_RETRIEVEMLDATASETASSPARKRESPONSE']._serialized_end=19316
  _globals['_RETRIEVEMLDATASETASSPARKRESPONSE_OPTIONSENTRY']._serialized_start=11532
  _globals['_RETRIEVEMLDATASETASSPARKRESPONSE_OPTIONSENTRY']._serialized_end=11578
  _globals['_RETRIEVEMLDATASETASASLINKSREQUEST']._serialized_start=19318
  _globals['_RETRIEVEMLDATASETASASLINKSREQUEST']._serialized_end=19376
  _globals['_RETRIEVEMLDATASETASASLINKSRESPONSE']._serialized_start=19378
  _globals['_RETRIEVEMLDATASETASASLINKSRESPONSE']._serialized_end=19438
  _globals['_RETRIEVEMLDATASETONLINEREQUEST']._serialized_start=19440
  _globals['_RETRIEVEMLDATASETONLINEREQUEST']._serialized_end=19509
  _globals['_FEATURESET']._serialized_start=19512
  _globals['_FEATURESET']._serialized_end=21375
  _globals['_FEATURESET_STATISTICS']._serialized_start=21004
  _globals['_FEATURESET_STATISTICS']._serialized_end=21038
  _globals['_FEATURESET_SPECIALDATA']._serialized_start=21041
  _globals['_FEATURESET_SPECIALDATA']._serialized_end=21299
  _globals['_FEATURESET_SPECIALDATA_LEGAL']._serialized_start=21208
  _globals['_FEATURESET_SPECIALDATA_LEGAL']._serialized_end=21299
  _globals['_FEATURESET_ONLINE']._serialized_start=21301
  _globals['_FEATURESET_ONLINE']._serialized_end=21375
  _globals['_GETFEATURESETPREVIEWREQUEST']._serialized_start=21377
  _globals['_GETFEATURESETPREVIEWREQUEST']._serialized_end=21459
  _globals['_GETFEATURESETPREVIEWRESPONSE']._serialized_start=21461
  _globals['_GETFEATURESETPREVIEWRESPONSE']._serialized_end=21534
  _globals['_SCOPE']._serialized_start=21536
  _globals['_SCOPE']._serialized_end=21647
  _globals['_REGISTERFEATURESETREQUEST']._serialized_start=21650
  _globals['_REGISTERFEATURESETREQUEST']._serialized_end=22625
  _globals['_CREATENEWFEATURESETVERSIONREQUEST']._serialized_start=22628
  _globals['_CREATENEWFEATURESETVERSIONREQUEST']._serialized_end=23035
  _globals['_FEATUREPROFILE']._serialized_start=23038
  _globals['_FEATUREPROFILE']._serialized_end=23293
  _globals['_FEATURESCHEMA']._serialized_start=23296
  _globals['_FEATURESCHEMA']._serialized_end=23679
  _globals['_FEATURESCHEMA_SPECIALDATA']._serialized_start=21041
  _globals['_FEATURESCHEMA_SPECIALDATA']._serialized_end=21133
  _globals['_FEATURE']._serialized_start=23682
  _globals['_FEATURE']._serialized_end=24378
  _globals['_FEATURE_MONITORING']._serialized_start=24245
  _globals['_FEATURE_MONITORING']._serialized_end=24284
  _globals['_FEATURE_SPECIALDATA']._serialized_start=21041
  _globals['_FEATURE_SPECIALDATA']._serialized_end=21133
  _globals['_FEATURESTATISTICS']._serialized_start=24381
  _globals['_FEATURESTATISTICS']._serialized_end=24553
  _globals['_CATEGORICALFEATURESTATISTICS']._serialized_start=24556
  _globals['_CATEGORICALFEATURESTATISTICS']._serialized_end=24727
  _globals['_CATEGORICALFEATURESTATISTICS_FEATURETOP']._serialized_start=24686
  _globals['_CATEGORICALFEATURESTATISTICS_FEATURETOP']._serialized_end=24727
  _globals['_GETVERSIONRESPONSE']._serialized_start=24729
  _globals['_GETVERSIONRESPONSE']._serialized_end=24766
  _globals['_PROJECT']._serialized_start=24769
  _globals['_PROJECT']._serialized_end=25162
  _globals['_LISTABLEPROJECT']._serialized_start=25165
  _globals['_LISTABLEPROJECT']._serialized_end=25457
  _globals['_FEATURESETINGEST']._serialized_start=25460
  _globals['_FEATURESETINGEST']._serialized_end=25739
  _globals['_PERSONALACCESSTOKEN']._serialized_start=25742
  _globals['_PERSONALACCESSTOKEN']._serialized_end=25957
  _globals['_GENERATETRANSFORMATIONUPLOADREQUEST']._serialized_start=25960
  _globals['_GENERATETRANSFORMATIONUPLOADREQUEST']._serialized_end=26096
  _globals['_GENERATETRANSFORMATIONUPLOADRESPONSE']._serialized_start=26099
  _globals['_GENERATETRANSFORMATIONUPLOADRESPONSE']._serialized_end=26312
  _globals['_GENERATETRANSFORMATIONUPLOADRESPONSE_HEADERSENTRY']._serialized_start=26266
  _globals['_GENERATETRANSFORMATIONUPLOADRESPONSE_HEADERSENTRY']._serialized_end=26312
  _globals['_LISTPROJECTSPAGEREQUEST']._serialized_start=26314
  _globals['_LISTPROJECTSPAGEREQUEST']._serialized_end=26378
  _globals['_LISTPROJECTSPAGERESPONSE']._serialized_start=26380
  _globals['_LISTPROJECTSPAGERESPONSE']._serialized_end=26486
  _globals['_SEARCHREQUEST']._serialized_start=26488
  _globals['_SEARCHREQUEST']._serialized_end=26598
  _globals['_PROJECTSEARCHRESULTS']._serialized_start=26600
  _globals['_PROJECTSEARCHRESULTS']._serialized_end=26718
  _globals['_LISTABLEFEATURESET']._serialized_start=26721
  _globals['_LISTABLEFEATURESET']._serialized_end=27759
  _globals['_FEATURESETSEARCHRESULTS']._serialized_start=27762
  _globals['_FEATURESETSEARCHRESULTS']._serialized_end=27890
  _globals['_LISTABLEFEATURE']._serialized_start=27893
  _globals['_LISTABLEFEATURE']._serialized_end=28115
  _globals['_FEATURESEARCHRESULTS']._serialized_start=28117
  _globals['_FEATURESEARCHRESULTS']._serialized_end=28235
  _globals['_FEATURESETREQUESTID']._serialized_start=28237
  _globals['_FEATURESETREQUESTID']._serialized_end=28282
  _globals['_GETFEATUREREQUEST']._serialized_start=28284
  _globals['_GETFEATUREREQUEST']._serialized_end=28376
  _globals['_LISTFEATURESPAGERESPONSE']._serialized_start=28378
  _globals['_LISTFEATURESPAGERESPONSE']._serialized_end=28484
  _globals['_FEATURERESPONSE']._serialized_start=28486
  _globals['_FEATURERESPONSE']._serialized_end=28557
  _globals['_LISTFEATURESREQUEST']._serialized_start=28559
  _globals['_LISTFEATURESREQUEST']._serialized_end=28658
  _globals['_LISTFEATURESRESPONSE']._serialized_start=28660
  _globals['_LISTFEATURESRESPONSE']._serialized_end=28762
  _globals['_LISTABLEFEATURESETREQUEST']._serialized_start=28764
  _globals['_LISTABLEFEATURESETREQUEST']._serialized_end=28844
  _globals['_LISTABLEFEATURESETRESPONSE']._serialized_start=28846
  _globals['_LISTABLEFEATURESETRESPONSE']._serialized_end=28952
  _globals['_SUBMITPENDINGPERMISSIONREQUEST']._serialized_start=28955
  _globals['_SUBMITPENDINGPERMISSIONREQUEST']._serialized_end=29088
  _globals['_SUBMITPENDINGPERMISSIONRESPONSE']._serialized_start=29090
  _globals['_SUBMITPENDINGPERMISSIONRESPONSE']._serialized_end=29146
  _globals['_LISTPERMISSIONSPAGEREQUEST']._serialized_start=29149
  _globals['_LISTPERMISSIONSPAGEREQUEST']._serialized_end=29278
  _globals['_LISTPROJECTSPERMISSIONSPAGERESPONSE']._serialized_start=29281
  _globals['_LISTPROJECTSPERMISSIONSPAGERESPONSE']._serialized_end=29417
  _globals['_LISTFEATURESETSPERMISSIONSPAGERESPONSE']._serialized_start=29420
  _globals['_LISTFEATURESETSPERMISSIONSPAGERESPONSE']._serialized_end=29562
  _globals['_LISTABLEPROJECTTOPERMISSION']._serialized_start=29565
  _globals['_LISTABLEPROJECTTOPERMISSION']._serialized_end=29716
  _globals['_LISTABLEFEATURESETTOPERMISSION']._serialized_start=29719
  _globals['_LISTABLEFEATURESETTOPERMISSION']._serialized_end=29880
  _globals['_PERMISSION']._serialized_start=29883
  _globals['_PERMISSION']._serialized_end=31015
  _globals['_PERMISSION_PROMOTEDUPDATE']._serialized_start=30555
  _globals['_PERMISSION_PROMOTEDUPDATE']._serialized_end=30727
  _globals['_PERMISSION_REVOKEDUPDATE']._serialized_start=30730
  _globals['_PERMISSION_REVOKEDUPDATE']._serialized_end=30866
  _globals['_PERMISSION_GRANTEDORREJECTEDUPDATE']._serialized_start=30869
  _globals['_PERMISSION_GRANTEDORREJECTEDUPDATE']._serialized_end=31015
  _globals['_REVOKEPERMISSIONREQUEST']._serialized_start=31017
  _globals['_REVOKEPERMISSIONREQUEST']._serialized_end=31081
  _globals['_APPROVEPENDINGPERMISSIONREQUEST']._serialized_start=31083
  _globals['_APPROVEPENDINGPERMISSIONREQUEST']._serialized_end=31155
  _globals['_REJECTPENDINGPERMISSIONREQUEST']._serialized_start=31157
  _globals['_REJECTPENDINGPERMISSIONREQUEST']._serialized_end=31228
  _globals['_GETACTIVEPERMISSIONREQUEST']._serialized_start=31230
  _globals['_GETACTIVEPERMISSIONREQUEST']._serialized_end=31279
  _globals['_GETACTIVEPERMISSIONRESPONSE']._serialized_start=31281
  _globals['_GETACTIVEPERMISSIONRESPONSE']._serialized_end=31376
  _globals['_SCHEDULEDTASK']._serialized_start=31379
  _globals['_SCHEDULEDTASK']._serialized_end=31945
  _globals['_SCHEDULETASKREQUEST']._serialized_start=31948
  _globals['_SCHEDULETASKREQUEST']._serialized_end=32236
  _globals['_LISTSCHEDULEDTASKSREQUEST']._serialized_start=32238
  _globals['_LISTSCHEDULEDTASKSREQUEST']._serialized_end=32328
  _globals['_LISTSCHEDULEDTASKSRESPONSE']._serialized_start=32330
  _globals['_LISTSCHEDULEDTASKSRESPONSE']._serialized_end=32441
  _globals['_SCHEDULEDTASKID']._serialized_start=32443
  _globals['_SCHEDULEDTASKID']._serialized_end=32487
  _globals['_SCHEDULEDTASKRESPONSE']._serialized_start=32489
  _globals['_SCHEDULEDTASKRESPONSE']._serialized_end=32569
  _globals['_SCHEDULEDTASKUPDATEREQUEST']._serialized_start=32571
  _globals['_SCHEDULEDTASKUPDATEREQUEST']._serialized_end=32689
  _globals['_LAZYINGESTREQUEST']._serialized_start=32691
  _globals['_LAZYINGESTREQUEST']._serialized_end=32763
  _globals['_LAZYINGESTRESPONSE']._serialized_start=32765
  _globals['_LAZYINGESTRESPONSE']._serialized_end=32836
  _globals['_GETLAZYINGESTTASKREQUEST']._serialized_start=32838
  _globals['_GETLAZYINGESTTASKREQUEST']._serialized_end=32917
  _globals['_TRANSFORMATIONFUNCTION']._serialized_start=32919
  _globals['_TRANSFORMATIONFUNCTION']._serialized_end=33018
  _globals['_LISTTRANSFORMATIONFUNCTIONSREQUEST']._serialized_start=33020
  _globals['_LISTTRANSFORMATIONFUNCTIONSREQUEST']._serialized_end=33056
  _globals['_LISTTRANSFORMATIONFUNCTIONSRESPONSE']._serialized_start=33058
  _globals['_LISTTRANSFORMATIONFUNCTIONSRESPONSE']._serialized_end=33181
  _globals['_GETTRANSFORMATIONFUNCTIONREQUEST']._serialized_start=33183
  _globals['_GETTRANSFORMATIONFUNCTIONREQUEST']._serialized_end=33255
  _globals['_GETTRANSFORMATIONFUNCTIONRESPONSE']._serialized_start=33257
  _globals['_GETTRANSFORMATIONFUNCTIONRESPONSE']._serialized_end=33377
  _globals['_UPDATEPROJECTREQUEST']._serialized_start=33380
  _globals['_UPDATEPROJECTREQUEST']._serialized_end=33598
  _globals['_UPDATEFEATURESETREQUEST']._serialized_start=33601
  _globals['_UPDATEFEATURESETREQUEST']._serialized_end=34557
  _globals['_UPDATEFEATUREREQUEST']._serialized_start=34560
  _globals['_UPDATEFEATUREREQUEST']._serialized_end=34955
  _globals['_GETOWNERSREQUEST']._serialized_start=34957
  _globals['_GETOWNERSREQUEST']._serialized_end=34996
  _globals['_GETOWNERSRESPONSE']._serialized_start=34998
  _globals['_GETOWNERSRESPONSE']._serialized_end=35076
  _globals['_BACKFILLOPTIONS']._serialized_start=35079
  _globals['_BACKFILLOPTIONS']._serialized_end=35436
  _globals['_BACKFILLOPTIONS_FEATUREMAPPINGENTRY']._serialized_start=35383
  _globals['_BACKFILLOPTIONS_FEATUREMAPPINGENTRY']._serialized_end=35436
  _globals['_BACKFILLRESPONSE']._serialized_start=35438
  _globals['_BACKFILLRESPONSE']._serialized_end=35525
  _globals['_CORESERVICE']._serialized_start=38203
  _globals['_CORESERVICE']._serialized_end=63464
# @@protoc_insertion_point(module_scope)
